@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2008-2022 The Octave Project Developers
+// Copyright (C) 2008-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -167,7 +167,7 @@ parse_range_spec (const octave_value& range_spec,
   return stat;
 }
 
-OCTAVE_NAMESPACE_BEGIN
+OCTAVE_BEGIN_NAMESPACE(octave)
 
 DEFMETHOD (dlmread, interp, args, ,
            doc: /* -*- texinfo -*-
@@ -341,7 +341,7 @@ such as text, are also replaced by the @qcode{"emptyvalue"}.
   std::string old_locale (prev_locale ? prev_locale : "");
   std::setlocale (LC_ALL, "C");
   unwind_action act
-    ([old_locale] () { std::setlocale (LC_ALL, old_locale.c_str ()); });
+  ([old_locale] () { std::setlocale (LC_ALL, old_locale.c_str ()); });
 
   std::string line;
 
@@ -767,4 +767,4 @@ such as text, are also replaced by the @qcode{"emptyvalue"}.
 
 */
 
-OCTAVE_NAMESPACE_END
+OCTAVE_END_NAMESPACE(octave)
