@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1996-2021 The Octave Project Developers
+// Copyright (C) 1996-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -34,6 +34,8 @@
 #include "errwarn.h"
 #include "ovl.h"
 
+OCTAVE_BEGIN_NAMESPACE(octave)
+
 // Find at most N_TO_FIND nonzero elements in NDA.  Search forward if
 // DIRECTION is 1, backward if it is -1.  NARGOUT is the number of
 // output arguments.  If N_TO_FIND is -1, find all nonzero elements.
@@ -52,7 +54,8 @@ find_nonzero_elem_idx (const Array<T>& nda, int nargout,
     idx = nda.find ();
 
   // The maximum element is always at the end.
-  octave_idx_type iext = (idx.isempty () ? 0 : idx.xelem (idx.numel () - 1) + 1);
+  octave_idx_type iext = (idx.isempty () ? 0
+                          : idx.xelem (idx.numel () - 1) + 1);
 
   switch (nargout)
     {
@@ -375,6 +378,10 @@ containing the nonzero values.  For example:
 @end group
 @end example
 
+If @var{x} is a multi-dimensional array of size m x n x p x @dots{}, @var{j}
+contains the column locations as if @var{x} was flattened into a
+two-dimensional matrix of size m x (n + p + @dots{}).
+
 Note that this function is particularly useful for sparse matrices, as
 it extracts the nonzero elements as vectors, which can then be used to
 create the original matrix.  For example:
@@ -400,10 +407,10 @@ b = sparse (i, j, v, sz(1), sz(2));
     {
       double val = args(1).xscalar_value ("find: N must be an integer");
 
-      if (val < 0 || (! octave::math::isinf (val)
-                      && val != octave::math::fix (val)))
+      if (val < 0 || (! math::isinf (val)
+                      && val != math::fix (val)))
         error ("find: N must be a non-negative integer");
-      else if (! octave::math::isinf (val))
+      else if (! math::isinf (val))
         n_to_find = val;
     }
 
@@ -586,6 +593,15 @@ b = sparse (i, j, v, sz(1), sz(2));
 %! assert (j, jfull);
 %! assert (all (v == 1));
 
+%!test <*61986>
+%! P = cat (3, eye(3), eye(3));
+%! loc = find (P);
+%! [i, j, v] = find(P);
+%! assert (loc, [1, 5, 9, 10, 14, 18]');
+%! assert (i, [1, 2, 3, 1, 2, 3]');
+%! assert (j, [1, 2, 3, 4, 5, 6]');
+%! assert (v, [1, 1, 1, 1, 1, 1]');
+
 %!assert <*53655> (find (false), zeros (0, 0))
 %!assert <*53655> (find ([false, false]), zeros (1, 0))
 %!assert <*53655> (find ([false; false]), zeros (0, 1))
@@ -599,3 +615,5 @@ b = sparse (i, j, v, sz(1), sz(2));
 
 %!error find ()
 */
+
+OCTAVE_END_NAMESPACE(octave)
