@@ -1,24 +1,27 @@
-/*
-
-Copyright (C) 1996-2019 John W. Eaton
-
-This file is part of Octave.
-
-Octave is free software: you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Octave is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<https://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 1996-2023 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if defined (HAVE_CONFIG_H)
 #  include "config.h"
@@ -32,18 +35,21 @@ along with Octave; see the file COPYING.  If not, see
 #include "defun.h"
 #include "error.h"
 #include "errwarn.h"
+#include "interpreter-private.h"
 #include "pager.h"
 #include "parse.h"
+#include "ov.h"
 #include "ovl.h"
-#include "ov-fcn.h"
 #include "unwind-prot.h"
 #include "utils.h"
 #include "variables.h"
 
 #include "Quad-opts.cc"
 
+OCTAVE_BEGIN_NAMESPACE(octave)
+
 // Global pointer for user defined function required by quadrature functions.
-static octave_function *quad_fcn;
+static octave_value quad_fcn;
 
 // Have we warned about imaginary values returned from user function?
 static bool warned_imaginary = false;
@@ -51,7 +57,7 @@ static bool warned_imaginary = false;
 // Is this a recursive call?
 static int call_depth = 0;
 
-double
+static double
 quad_user_function (double x)
 {
   double retval = 0.0;
@@ -59,17 +65,17 @@ quad_user_function (double x)
   octave_value_list args;
   args(0) = x;
 
-  if (quad_fcn)
+  if (quad_fcn.is_defined ())
     {
       octave_value_list tmp;
 
       try
         {
-          tmp = octave::feval (quad_fcn, args, 1);
+          tmp = feval (quad_fcn, args, 1);
         }
-      catch (octave::execution_exception& e)
+      catch (execution_exception& ee)
         {
-          err_user_supplied_eval (e, "quad");
+          err_user_supplied_eval (ee, "quad");
         }
 
       if (! tmp.length () || ! tmp(0).is_defined ())
@@ -87,7 +93,7 @@ quad_user_function (double x)
   return retval;
 }
 
-float
+static float
 quad_float_user_function (float x)
 {
   float retval = 0.0;
@@ -95,17 +101,17 @@ quad_float_user_function (float x)
   octave_value_list args;
   args(0) = x;
 
-  if (quad_fcn)
+  if (quad_fcn.is_defined ())
     {
       octave_value_list tmp;
 
       try
         {
-          tmp = octave::feval (quad_fcn, args, 1);
+          tmp = feval (quad_fcn, args, 1);
         }
-      catch (octave::execution_exception& e)
+      catch (execution_exception& ee)
         {
-          err_user_supplied_eval (e, "quad");
+          err_user_supplied_eval (ee, "quad");
         }
 
       if (! tmp.length () || ! tmp(0).is_defined ())
@@ -128,7 +134,7 @@ DEFMETHODX ("quad", Fquad, interp, args, ,
 @deftypefn  {} {@var{q} =} quad (@var{f}, @var{a}, @var{b})
 @deftypefnx {} {@var{q} =} quad (@var{f}, @var{a}, @var{b}, @var{tol})
 @deftypefnx {} {@var{q} =} quad (@var{f}, @var{a}, @var{b}, @var{tol}, @var{sing})
-@deftypefnx {} {[@var{q}, @var{ier}, @var{nfun}, @var{err}] =} quad (@dots{})
+@deftypefnx {} {[@var{q}, @var{ier}, @var{nfev}, @var{err}] =} quad (@dots{})
 Numerically evaluate the integral of @var{f} from @var{a} to @var{b} using
 Fortran routines from @w{@sc{quadpack}}.
 
@@ -155,7 +161,7 @@ The result of the integration is returned in @var{q}.
 @var{ier} contains an integer error code (0 indicates a successful
 integration).
 
-@var{nfun} indicates the number of function evaluations that were
+@var{nfev} indicates the number of function evaluations that were
 made.
 
 @var{err} contains an estimate of the error in the solution.
@@ -176,32 +182,13 @@ variable by routines @code{dblquad} and @code{triplequad}.
 
   warned_imaginary = false;
 
-  octave::unwind_protect frame;
-
-  frame.protect_var (call_depth);
+  unwind_protect_var<int> restore_var (call_depth);
   call_depth++;
 
   if (call_depth > 1)
     error ("quad: invalid recursive call");
 
-  std::string fcn_name;
-
-  if (args(0).is_function_handle () || args(0).is_inline_function ())
-    quad_fcn = args(0).function_value ();
-  else
-    {
-      fcn_name = unique_symbol_name ("__quad_fcn__");
-      std::string fname = "function y = ";
-      fname.append (fcn_name);
-      fname.append ("(x) y = ");
-      quad_fcn = extract_function (args(0), "quad", fcn_name, fname,
-                                   "; endfunction");
-      octave::symbol_table& symtab = interp.get_symbol_table ();
-      frame.add_method (symtab, &octave::symbol_table::clear_function, fcn_name);
-    }
-
-  if (! quad_fcn)
-    error ("quad: FCN argument is not a valid function name or handle");
+  quad_fcn = get_function_handle (interp, args(0), "x");
 
   octave_value_list retval;
 
@@ -214,18 +201,18 @@ variable by routines @code{dblquad} and @code{triplequad}.
       FloatIndefQuad::IntegralType indef_type
         = FloatIndefQuad::doubly_infinite;
       float bound = 0.0;
-      if (octave::math::isinf (a) && octave::math::isinf (b))
+      if (math::isinf (a) && math::isinf (b))
         {
           indefinite = 1;
           indef_type = FloatIndefQuad::doubly_infinite;
         }
-      else if (octave::math::isinf (a))
+      else if (math::isinf (a))
         {
           indefinite = 1;
           bound = b;
           indef_type = FloatIndefQuad::neg_inf_to_bound;
         }
-      else if (octave::math::isinf (b))
+      else if (math::isinf (b))
         {
           indefinite = 1;
           bound = a;
@@ -233,7 +220,7 @@ variable by routines @code{dblquad} and @code{triplequad}.
         }
 
       octave_idx_type ier = 0;
-      octave_idx_type nfun = 0;
+      octave_idx_type nfev = 0;
       float abserr = 0.0;
       float val = 0.0;
       bool have_sing = false;
@@ -275,7 +262,7 @@ variable by routines @code{dblquad} and @code{triplequad}.
               FloatIndefQuad iq (quad_float_user_function, bound,
                                  indef_type);
               iq.set_options (quad_opts);
-              val = iq.float_integrate (ier, nfun, abserr);
+              val = iq.float_integrate (ier, nfev, abserr);
             }
           else
             {
@@ -283,13 +270,13 @@ variable by routines @code{dblquad} and @code{triplequad}.
                 {
                   FloatDefQuad dq (quad_float_user_function, a, b, sing);
                   dq.set_options (quad_opts);
-                  val = dq.float_integrate (ier, nfun, abserr);
+                  val = dq.float_integrate (ier, nfev, abserr);
                 }
               else
                 {
                   FloatDefQuad dq (quad_float_user_function, a, b);
                   dq.set_options (quad_opts);
-                  val = dq.float_integrate (ier, nfun, abserr);
+                  val = dq.float_integrate (ier, nfev, abserr);
                 }
             }
           break;
@@ -299,7 +286,7 @@ variable by routines @code{dblquad} and @code{triplequad}.
           break;
         }
 
-      retval = ovl (val, ier, nfun, abserr);
+      retval = ovl (val, ier, nfev, abserr);
 
     }
   else
@@ -310,18 +297,18 @@ variable by routines @code{dblquad} and @code{triplequad}.
       int indefinite = 0;
       IndefQuad::IntegralType indef_type = IndefQuad::doubly_infinite;
       double bound = 0.0;
-      if (octave::math::isinf (a) && octave::math::isinf (b))
+      if (math::isinf (a) && math::isinf (b))
         {
           indefinite = 1;
           indef_type = IndefQuad::doubly_infinite;
         }
-      else if (octave::math::isinf (a))
+      else if (math::isinf (a))
         {
           indefinite = 1;
           bound = b;
           indef_type = IndefQuad::neg_inf_to_bound;
         }
-      else if (octave::math::isinf (b))
+      else if (math::isinf (b))
         {
           indefinite = 1;
           bound = a;
@@ -329,7 +316,7 @@ variable by routines @code{dblquad} and @code{triplequad}.
         }
 
       octave_idx_type ier = 0;
-      octave_idx_type nfun = 0;
+      octave_idx_type nfev = 0;
       double abserr = 0.0;
       double val = 0.0;
       bool have_sing = false;
@@ -370,7 +357,7 @@ variable by routines @code{dblquad} and @code{triplequad}.
             {
               IndefQuad iq (quad_user_function, bound, indef_type);
               iq.set_options (quad_opts);
-              val = iq.integrate (ier, nfun, abserr);
+              val = iq.integrate (ier, nfev, abserr);
             }
           else
             {
@@ -378,13 +365,13 @@ variable by routines @code{dblquad} and @code{triplequad}.
                 {
                   DefQuad dq (quad_user_function, a, b, sing);
                   dq.set_options (quad_opts);
-                  val = dq.integrate (ier, nfun, abserr);
+                  val = dq.integrate (ier, nfev, abserr);
                 }
               else
                 {
                   DefQuad dq (quad_user_function, a, b);
                   dq.set_options (quad_opts);
-                  val = dq.integrate (ier, nfun, abserr);
+                  val = dq.integrate (ier, nfev, abserr);
                 }
             }
           break;
@@ -394,7 +381,7 @@ variable by routines @code{dblquad} and @code{triplequad}.
           break;
         }
 
-      retval = ovl (val, ier, nfun, abserr);
+      retval = ovl (val, ier, nfev, abserr);
     }
 
   return retval;
@@ -406,17 +393,17 @@ variable by routines @code{dblquad} and @code{triplequad}.
 %!endfunction
 
 %!test
-%! [v, ier, nfun, err] = quad ("__f", 0, 5);
+%! [v, ier, nfev, err] = quad ("__f", 0, 5);
 %! assert (ier, 0);
 %! assert (v, 17.5, sqrt (eps));
-%! assert (nfun > 0);
+%! assert (nfev > 0);
 %! assert (err < sqrt (eps));
 
 %!test
-%! [v, ier, nfun, err] = quad ("__f", single (0), single (5));
+%! [v, ier, nfev, err] = quad ("__f", single (0), single (5));
 %! assert (ier, 0);
 %! assert (v, 17.5, sqrt (eps ("single")));
-%! assert (nfun > 0);
+%! assert (nfev > 0);
 %! assert (err < sqrt (eps ("single")));
 
 %!function y = __f (x)
@@ -424,16 +411,43 @@ variable by routines @code{dblquad} and @code{triplequad}.
 %!endfunction
 
 %!test
-%!  [v, ier, nfun, err] = quad ("__f", 0.001, 3);
+%!  [v, ier, nfev, err] = quad ("__f", 0.001, 3);
 %! assert (ier == 0 || ier == 1);
 %! assert (v, 1.98194120273598, sqrt (eps));
-%! assert (nfun > 0);
+%! assert (nfev > 0);
 
 %!test
-%!  [v, ier, nfun, err] = quad ("__f", single (0.001), single (3));
+%!  [v, ier, nfev, err] = quad (@__f, 0.001, 3);
+%! assert (ier == 0 || ier == 1);
+%! assert (v, 1.98194120273598, sqrt (eps));
+%! assert (nfev > 0);
+
+%!test
+%!  fstr = "x .* sin (1 ./ x) .* sqrt (abs (1 - x))";
+%!  [v, ier, nfev, err] = quad (fstr, 0.001, 3);
+%! assert (ier == 0 || ier == 1);
+%! assert (v, 1.98194120273598, sqrt (eps));
+%! assert (nfev > 0);
+
+%!test
+%!  anon_fcn = @(x) x .* sin (1 ./ x) .* sqrt (abs (1 - x));
+%!  [v, ier, nfev, err] = quad (anon_fcn, 0.001, 3);
+%! assert (ier == 0 || ier == 1);
+%! assert (v, 1.98194120273598, sqrt (eps));
+%! assert (nfev > 0);
+
+%!test
+%!  inline_fcn = inline ("x .* sin (1 ./ x) .* sqrt (abs (1 - x))", "x");
+%!  [v, ier, nfev, err] = quad (inline_fcn, 0.001, 3);
+%! assert (ier == 0 || ier == 1);
+%! assert (v, 1.98194120273598, sqrt (eps));
+%! assert (nfev > 0);
+
+%!test
+%!  [v, ier, nfev, err] = quad ("__f", single (0.001), single (3));
 %! assert (ier == 0 || ier == 1);
 %! assert (v, 1.98194120273598, sqrt (eps ("single")));
-%! assert (nfun > 0);
+%! assert (nfev > 0);
 
 %!error quad ()
 %!error quad ("__f", 1, 2, 3, 4, 5)
@@ -444,3 +458,5 @@ variable by routines @code{dblquad} and @code{triplequad}.
 
 %!error quad_options (1, 2, 3)
 */
+
+OCTAVE_END_NAMESPACE(octave)
