@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2009-2021 The Octave Project Developers
+// Copyright (C) 2009-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -27,6 +27,8 @@
 #  include "config.h"
 #endif
 
+#include <utility>
+
 #include "Array-util.h"
 #include "oct-locbuf.h"
 #include "quit.h"
@@ -36,6 +38,7 @@
 #include "errwarn.h"
 #include "ovl.h"
 
+OCTAVE_BEGIN_NAMESPACE(octave)
 
 static dim_vector
 get_dim_vector (const octave_value& val, const char *name)
@@ -68,8 +71,8 @@ DEFUN (sub2ind, args, ,
 Convert subscripts to linear indices.
 
 The input @var{dims} is a dimension vector where each element is the size of
-the array in the respective dimension (@pxref{XREFsize,,size}).  The remaining
-inputs are scalars or vectors of subscripts to be converted.
+the array in the respective dimension (@pxref{XREFsize,,@code{size}}).  The
+remaining inputs are scalars or vectors of subscripts to be converted.
 
 The output vector @var{ind} contains the converted linear indices.
 
@@ -130,12 +133,12 @@ ind = sub2ind ([3, 3], s1, s2)
           if (j > 0 && args(j+1).dims () != args(1).dims ())
             error ("sub2ind: all subscripts must be of the same size");
         }
-      catch (octave::index_exception& e)
+      catch (index_exception& ie)
         {
-          e.set_pos_if_unset (nargin-1, j+1);
-          e.set_var ();
-          std::string msg = e.message ();
-          error_with_id (e.err_id (), "%s", msg.c_str ());
+          ie.set_pos_if_unset (nargin-1, j+1);
+          ie.set_var ();
+          std::string msg = ie.message ();
+          error_with_id (ie.err_id (), "%s", msg.c_str ());
         }
     }
 
@@ -193,8 +196,8 @@ DEFUN (ind2sub, args, nargout,
 Convert linear indices to subscripts.
 
 The input @var{dims} is a dimension vector where each element is the size of
-the array in the respective dimension (@pxref{XREFsize,,size}).  The second
-input @var{ind} contains linear indies to be converted.
+the array in the respective dimension (@pxref{XREFsize,,@code{size}}).  The
+second input @var{ind} contains linear indices to be converted.
 
 The outputs @var{s1}, @dots{}, @var{sN} contain the converted subscripts.
 
@@ -219,12 +222,8 @@ Consider the following 3-by-3 matrices:
 The left matrix contains the linear indices for each matrix element.  The right
 matrix shows the subscript tuples for the same matrix.
 
-The following example shows how to convert the two-dimensional indices
-@code{(2,1)} and @code{(2,3)} of a 3-by-3 matrix to linear indices with a
-single call to @code{sub2ind}.
-
 The following example shows how to convert the linear indices @code{2} and
-@code{8} in a 3-by-3 matrix into subscripts.
+@code{8} to appropriate subscripts of a 3-by-3 matrix.
 
 @example
 @group
@@ -255,7 +254,7 @@ r = ind2sub (dims, ind)
     @result{} r =  2   8
 @end group
 @end example
-@seealso{ind2sub, size}
+@seealso{sub2ind, size}
 @end deftypefn */)
 {
   if (args.length () != 2)
@@ -263,16 +262,24 @@ r = ind2sub (dims, ind)
 
   octave_value_list retval;
 
-  // Redimension to provided number of subscripts.
+  int nd = (nargout == 0) ? 1 : nargout;
+
   dim_vector dv = get_dim_vector (args(0), "ind2sub").redim (nargout);
 
+  // Redim for 1 will give us a column vector but we want a row vector.
+  if (nd == 1)
+    std::swap (dv(0), dv(1));
+
   try
     {
       retval = Array<octave_value> (ind2sub (dv, args(1).index_vector ()));
+
+      if (nd == 1)
+        retval(0) = retval(1);
     }
-  catch (const octave::index_exception& e)
+  catch (const index_exception& ie)
     {
-      error ("ind2sub: invalid index %s", e.what ());
+      error ("ind2sub: invalid index %s", ie.what ());
     }
 
   return retval;
@@ -313,7 +320,19 @@ r = ind2sub (dims, ind)
 %! r = ind2sub ([2, 2, 2], 1:8);
 %! assert (r, 1:8);
 
-%!error <DIMS must contain integers> ind2sub ([2, -2], 3);
-%!error <index out of range> ind2sub ([2, 2, 2], 1:9);
-%!error <invalid index> ind2sub ([2, 2, 2], -1:8);
+## Indexing beyond specified size (bug #62184)
+%!assert <*62184> (ind2sub (1, 2), 2)
+%!assert <*62184> (ind2sub ([3,3], 10), 10)
+%!test <*62184>
+%! [r,c] = ind2sub ([3,3], 10);
+%! assert ([r, c], [1, 4]);
+%!test <*62184>
+%! [r,c,p] = ind2sub ([3,3], 10);
+%! assert ([r, c, p], [1, 1, 2]);
+
+## Test input validation
+%!error <DIMS must contain integers> ind2sub ([2, -2], 3)
+%!error <invalid index> ind2sub ([2, 2, 2], -1:8)
 */
+
+OCTAVE_END_NAMESPACE(octave)
