@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2007-2021 The Octave Project Developers
+// Copyright (C) 2007-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -38,6 +38,8 @@
 #include "ovl.h"
 #include "unwind-prot.h"
 
+OCTAVE_BEGIN_NAMESPACE(octave)
+
 static dim_vector
 get_vec_dims (const dim_vector& old_dims, octave_idx_type n)
 {
@@ -52,10 +54,10 @@ get_vec_dims (const dim_vector& old_dims, octave_idx_type n)
 template <typename ArrayType>
 static void
 get_data_and_bytesize (const ArrayType& array,
-                       const void *& data,
+                       const void *&data,
                        octave_idx_type& byte_size,
                        dim_vector& old_dims,
-                       octave::unwind_protect& frame)
+                       unwind_protect& frame)
 {
   // The array given may be a temporary, constructed from a scalar or sparse
   // array.  This will ensure the data will be deallocated after we exit.
@@ -164,7 +166,7 @@ typecast (@var{x}, "uint8")
 
   octave_value retval;
 
-  octave::unwind_protect frame;
+  unwind_protect frame;
 
   const void *data = nullptr;
   octave_idx_type byte_size = 0;
@@ -204,8 +206,6 @@ typecast (@var{x}, "uint8")
       else if (array.is_uint64_type ())
         get_data_and_bytesize (array.uint64_array_value (), data, byte_size,
                                old_dims, frame);
-      else
-        assert (0);
     }
   else if (array.iscomplex ())
     {
@@ -237,8 +237,8 @@ typecast (@var{x}, "uint8")
     ;
   else if (numclass == "char")
     retval = octave_value (reinterpret_copy<charNDArray>
-                           (data, byte_size, old_dims), array.is_dq_string () ? '"'
-                           : '\'');
+                           (data, byte_size, old_dims),
+                           array.is_dq_string () ? '"' : '\'');
   else if (numclass[0] == 'i')
     {
       if (numclass == "int8")
@@ -256,13 +256,13 @@ typecast (@var{x}, "uint8")
         retval = reinterpret_int_copy<uint8NDArray> (data, byte_size, old_dims);
       else if (numclass == "uint16")
         retval = reinterpret_int_copy<uint16NDArray> (data, byte_size,
-                                                      old_dims);
+                 old_dims);
       else if (numclass == "uint32")
         retval = reinterpret_int_copy<uint32NDArray> (data, byte_size,
-                                                      old_dims);
+                 old_dims);
       else if (numclass == "uint64")
         retval = reinterpret_int_copy<uint64NDArray> (data, byte_size,
-                                                      old_dims);
+                 old_dims);
     }
   else if (numclass == "single")
     retval = reinterpret_copy<FloatNDArray> (data, byte_size, old_dims);
@@ -270,7 +270,7 @@ typecast (@var{x}, "uint8")
     retval = reinterpret_copy<NDArray> (data, byte_size, old_dims);
   else if (numclass == "single complex")
     retval = reinterpret_copy<FloatComplexNDArray> (data, byte_size,
-                                                    old_dims);
+             old_dims);
   else if (numclass == "double complex")
     retval = reinterpret_copy<ComplexNDArray> (data, byte_size, old_dims);
 
@@ -322,7 +322,7 @@ do_bitpack (const boolNDArray& bitp)
 
   ArrayType retval (get_vec_dims (bitp.dims (), n));
 
-  const bool *bits = bitp.fortran_vec ();
+  const bool *bits = bitp.data ();
   char *packed = reinterpret_cast<char *> (retval.fortran_vec ());
 
   octave_idx_type m = n * sizeof (T);
@@ -470,7 +470,7 @@ do_bitunpack (const ArrayType& array)
 
   boolNDArray retval (get_vec_dims (array.dims (), n));
 
-  const char *packed = reinterpret_cast<const char *> (array.fortran_vec ());
+  const char *packed = reinterpret_cast<const char *> (array.data ());
   bool *bits = retval.fortran_vec ();
 
   octave_idx_type m = n / std::numeric_limits<unsigned char>::digits;
@@ -546,8 +546,6 @@ column vector.
         retval = do_bitunpack (array.uint32_array_value ());
       else if (array.is_uint64_type ())
         retval = do_bitunpack (array.uint64_array_value ());
-      else
-        assert (0);
     }
   else if (array.iscomplex ())
     {
@@ -589,3 +587,5 @@ column vector.
 %!error bitunpack (1, 2)
 %!error bitunpack ({})
 */
+
+OCTAVE_END_NAMESPACE(octave)
