@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2007-2021 The Octave Project Developers
+// Copyright (C) 2007-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -42,8 +42,6 @@ To initialize:
 #include "error.h"
 #include "errwarn.h"
 
-#if defined (HAVE_FLTK)
-
 #if defined (HAVE_X_WINDOWS)
 #  include <X11/Xlib.h>
 #endif
@@ -60,20 +58,22 @@ To initialize:
 #  define WIN32_LEAN_AND_MEAN
 #endif
 
-#include <FL/Fl.H>
-#include <FL/Fl_Box.H>
-#include <FL/Fl_Button.H>
-#include <FL/Fl_Choice.H>
-#include <FL/Fl_File_Chooser.H>
-#include <FL/Fl_Gl_Window.H>
-#include <FL/names.h>
-#include <FL/Fl_Menu_Bar.H>
-#include <FL/Fl_Menu_Button.H>
-#include <FL/Fl_Output.H>
-#include <FL/Fl_Window.H>
-#include <FL/fl_ask.H>
-#include <FL/fl_draw.H>
-#include <FL/gl.h>
+#if defined (HAVE_FLTK)
+#  include <FL/Fl.H>
+#  include <FL/Fl_Box.H>
+#  include <FL/Fl_Button.H>
+#  include <FL/Fl_Choice.H>
+#  include <FL/Fl_File_Chooser.H>
+#  include <FL/Fl_Gl_Window.H>
+#  include <FL/names.h>
+#  include <FL/Fl_Menu_Bar.H>
+#  include <FL/Fl_Menu_Button.H>
+#  include <FL/Fl_Output.H>
+#  include <FL/Fl_Window.H>
+#  include <FL/fl_ask.H>
+#  include <FL/fl_draw.H>
+#  include <FL/gl.h>
+#endif
 
 // FLTK headers may include X11/X.h which defines Complex, and that
 // conflicts with Octave's Complex typedef.  We don't need the X11
@@ -105,6 +105,10 @@ To initialize:
 #include "parse.h"
 #include "variables.h"
 
+OCTAVE_BEGIN_NAMESPACE(octave)
+
+#if defined (HAVE_FLTK)
+
 #define FLTK_GRAPHICS_TOOLKIT_NAME "fltk"
 
 const char *help_text = "\
@@ -155,14 +159,14 @@ public:
 
   void print (const std::string& cmd, const std::string& term)
   {
-    gh_manager& gh_mgr = octave::__get_gh_manager__ ("OpenGL_fltk::print");
+    gh_manager& gh_mgr = octave::__get_gh_manager__ ();
 
     octave::gl2ps_print (m_glfcns, gh_mgr.get_object (m_number), cmd, term);
   }
 
   uint8NDArray get_pixels (void)
   {
-    gh_manager& gh_mgr = octave::__get_gh_manager__ ("OpenGL_fltk::get_pixels");
+    gh_manager& gh_mgr = octave::__get_gh_manager__ ();
 
     m_renderer.draw (gh_mgr.get_object (m_number));
 
@@ -226,7 +230,7 @@ private:
         m_glfcns.glViewport (0, 0, w (), h ());
       }
 
-    gh_manager& gh_mgr = octave::__get_gh_manager__ ("OpenGL_fltk::draw");
+    gh_manager& gh_mgr = octave::__get_gh_manager__ ();
 
     m_renderer.draw (gh_mgr.get_object (m_number));
 
@@ -291,9 +295,9 @@ private:
   }
 };
 
-void script_cb (Fl_Widget *, void *data)
+static void script_cb (Fl_Widget *, void *data)
 {
-  static_cast<uimenu::properties *> (data)->execute_callback ();
+  static_cast<uimenu::properties *> (data)->execute_menuselectedfcn ();
 }
 
 class fltk_uimenu
@@ -407,8 +411,7 @@ public:
 
     for (octave_idx_type ii = 0; ii < uimenu_childs.numel (); ii++)
       {
-        gh_manager& gh_mgr
-          = octave::__get_gh_manager__ ("fltk_uimenu::do_find_uimenu_children");
+        gh_manager& gh_mgr = octave::__get_gh_manager__ ();
 
         graphics_object kidgo = gh_mgr.get_object (uimenu_childs (ii));
 
@@ -459,7 +462,7 @@ public:
       }
   }
 
-  void update_callback (uimenu::properties& uimenup)
+  void update_menuselectedfcn (uimenu::properties& uimenup)
   {
     std::string fltk_label = uimenup.get___fltk_label__ ();
     if (! fltk_label.empty ())
@@ -468,7 +471,7 @@ public:
           = const_cast<Fl_Menu_Item *> (m_menubar->find_item (fltk_label.c_str ()));
         if (item)
           {
-            if (! uimenup.get_callback ().isempty ())
+            if (! uimenup.get_menuselectedfcn ().isempty ())
               item->callback (static_cast<Fl_Callback *> (script_cb),
                               static_cast<void *> (&uimenup));
             else
@@ -631,13 +634,13 @@ public:
 
     add_entry (uimenup);
     update_foregroundcolor (uimenup);
-    update_callback (uimenup);
+    update_menuselectedfcn (uimenup);
     update_accelerator (uimenup);
     update_enable (uimenup);
     update_visible (uimenup);
     update_seperator (uimenup);
 
-    gh_manager& gh_mgr = octave::__get_gh_manager__ ("fltk_uimenu::add_to_menu");
+    gh_manager& gh_mgr = octave::__get_gh_manager__ ();
 
     for (octave_idx_type ii = 0; ii < len; ii++)
       {
@@ -683,7 +686,7 @@ public:
 
     m_menubar->clear ();
 
-    gh_manager& gh_mgr = octave::__get_gh_manager__ ("fltk_uimenu::add_to_menu");
+    gh_manager& gh_mgr = octave::__get_gh_manager__ ();
 
     for (octave_idx_type ii = 0; ii < len; ii++)
       {
@@ -729,7 +732,7 @@ public:
     kids = find_uimenu_children (prop);
     int len = kids.numel ();
 
-    gh_manager& gh_mgr = octave::__get_gh_manager__ ("fltk_uimenu::remove_from_menu");
+    gh_manager& gh_mgr = octave::__get_gh_manager__ ();
 
     for (octave_idx_type ii = 0; ii < len; ii++)
       {
@@ -795,7 +798,7 @@ public:
                                  ww - 5 * m_status_h, hh);
 
     // See http://fltk.org/articles.php?L415+I0+T+M1000+P1
-    // for how resizable works
+                // for how resizable works
     resizable (m_resize_dummy);
 
     // FIXME: The function below is only available in FLTK >= 1.3
@@ -931,7 +934,7 @@ public:
 
   void uimenu_update (const graphics_handle& gh, int id)
   {
-    gh_manager& gh_mgr = octave::__get_gh_manager__ ("plot_window::uimenu_update");
+    gh_manager& gh_mgr = octave::__get_gh_manager__ ();
 
     graphics_object uimenu_obj = gh_mgr.get_object (gh);
 
@@ -958,8 +961,8 @@ public:
             m_uimenu->update_accelerator (uimenup);
             break;
 
-          case uimenu::properties::ID_CALLBACK:
-            m_uimenu->update_callback (uimenup);
+          case uimenu::properties::ID_MENUSELECTEDFCN:
+            m_uimenu->update_menuselectedfcn (uimenup);
             break;
 
           case uimenu::properties::ID_CHECKED:
@@ -1151,8 +1154,7 @@ private:
         graphics_handle gh = m_fp.get_currentaxes ();
         if (gh.ok ())
           {
-            gh_manager& gh_mgr
-              = octave::__get_gh_manager__ ("plot_window::set_on_ax_obj");
+            gh_manager& gh_mgr = octave::__get_gh_manager__ ();
 
             graphics_object go = gh_mgr.get_object (gh);
 
@@ -1189,7 +1191,7 @@ private:
   void pixel2pos (const graphics_handle& ax, int px, int py, double& xx,
                   double& yy) const
   {
-    gh_manager& gh_mgr = octave::__get_gh_manager__ ("plot_window::pixel2pos");
+    gh_manager& gh_mgr = octave::__get_gh_manager__ ();
 
     pixel2pos (gh_mgr.get_object (ax), px, py, xx, yy);
   }
@@ -1212,7 +1214,7 @@ private:
     Matrix kids = m_fp.get_children ();
     int len = kids.numel ();
 
-    gh_manager& gh_mgr = octave::__get_gh_manager__ ("plot_window::pixel2axes_or_ca");
+    gh_manager& gh_mgr = octave::__get_gh_manager__ ();
 
     for (int k = 0; k < len; k++)
       {
@@ -1240,7 +1242,7 @@ private:
   void pixel2status (const graphics_handle& ax, int px0, int py0,
                      int px1 = -1, int py1 = -1)
   {
-    gh_manager& gh_mgr = octave::__get_gh_manager__ ("plot_window::pixel2status");
+    gh_manager& gh_mgr = octave::__get_gh_manager__ ();
 
     pixel2status (gh_mgr.get_object (ax), px0, py0, px1, py1);
   }
@@ -1273,7 +1275,7 @@ private:
         std::stringstream cbuf;
         cbuf.precision (4);
         cbuf.width (6);
-        Matrix v (1,2,0);
+        Matrix v (1, 2, 0);
         v = ap.get ("view").matrix_value ();
         cbuf << "[azimuth: " << v(0) << ", elevation: " << v(1) << ']';
 
@@ -1288,8 +1290,7 @@ private:
         Matrix pos = m_fp.map_from_boundingbox (px, py);
         m_fp.set_currentpoint (pos);
 
-        gh_manager& gh_mgr
-          = octave::__get_gh_manager__ ("plot_window::set_currentpoint");
+        gh_manager& gh_mgr = octave::__get_gh_manager__ ();
 
         graphics_object robj = gh_mgr.get_object (m_fp.get_parent ());
 
@@ -1312,15 +1313,15 @@ private:
 
         // front point (nearest to the viewer)
         ColumnVector tmp = ap.get_transform ().untransform (px, py, x_zlim(0));
-        pos(0,0) = tmp(0);
-        pos(0,1) = tmp(1);
-        pos(0,2) = tmp(2);
+        pos(0, 0) = tmp(0);
+        pos(0, 1) = tmp(1);
+        pos(0, 2) = tmp(2);
 
         // back point (furthest from the viewer)
         tmp = ap.get_transform ().untransform (px, py, x_zlim(1));
-        pos(1,0) = tmp(0);
-        pos(1,1) = tmp(1);
-        pos(1,2) = tmp(2);
+        pos(1, 0) = tmp(0);
+        pos(1, 1) = tmp(1);
+        pos(1, 2) = tmp(2);
 
         ap.set_currentpoint (pos);
         if (ap.get_tag () != "legend" && ap.get_tag () != "colorbar")
@@ -1336,7 +1337,8 @@ private:
       return 0;
   }
 
-  octave_scalar_map format_key_event (int e_key, const char *e_text, int e_state)
+  octave_scalar_map format_key_event (int e_key, const char *e_text,
+                                      int e_state)
   {
     octave_scalar_map evt;
 
@@ -1508,7 +1510,7 @@ private:
         // See Event Propagation http://www.fltk.org/doc-1.3/events.html
         static bool key_resent_detected = false;
 
-        gh_manager& gh_mgr = octave::__get_gh_manager__ ("plot_window::handle");
+        gh_manager& gh_mgr = octave::__get_gh_manager__ ();
 
         switch (event)
           {
@@ -1521,9 +1523,9 @@ private:
               int e_key = Fl::event_key ();
               char e_text = Fl::event_text ()[0];
               key_resent_detected = (e_key == last_event_key
-                  && std::tolower (last_event_text) == std::tolower (e_text)
-                  && ((islower (last_event_text) && isupper (e_text))
-                      || (isupper (last_event_text) && islower (e_text))));
+                                     && std::tolower (last_event_text) == std::tolower (e_text)
+                                     && ((islower (last_event_text) && isupper (e_text))
+                                         || (isupper (last_event_text) && islower (e_text))));
 
               last_event_key = e_key;
               last_event_text = e_text;
@@ -1744,7 +1746,7 @@ private:
                 {
                   pixel2status (m_ax_obj, m_pos_x, m_pos_y,
                                 Fl::event_x (), Fl::event_y () - menu_dy ());
-                  Matrix zoom_box (1,4,0);
+                  Matrix zoom_box (1, 4, 0);
                   zoom_box(0) = m_pos_x;
                   zoom_box(1) = m_pos_y;
                   zoom_box(2) = Fl::event_x ();
@@ -1761,8 +1763,8 @@ private:
               {
                 graphics_object ax
                   = gh_mgr.get_object (pixel2axes_or_ca (Fl::event_x (),
-                                                         Fl::event_y ()
-                                                         - menu_dy ()));
+                                       Fl::event_y ()
+                                       - menu_dy ()));
                 if (ax && ax.isa ("axes"))
                   {
                     axes::properties& ap
@@ -1794,7 +1796,8 @@ private:
             case FL_RELEASE:
               if (! m_fp.get_windowbuttonupfcn ().isempty ())
                 {
-                  set_currentpoint (Fl::event_x (), Fl::event_y () - menu_dy ());
+                  set_currentpoint (Fl::event_x (),
+                                    Fl::event_y () - menu_dy ());
                   m_fp.execute_windowbuttonupfcn ();
                 }
 
@@ -1813,7 +1816,7 @@ private:
                   if (m_canvas->zoom ())
                     {
                       m_canvas->zoom (false);
-                      double x0,y0,x1,y1;
+                      double x0, y0, x1, y1;
                       if (m_ax_obj && m_ax_obj.isa ("axes"))
                         {
                           axes::properties& ap = dynamic_cast<axes::properties&>
@@ -1822,8 +1825,8 @@ private:
                           int pos_x1 = Fl::event_x ();
                           int pos_y1 = Fl::event_y () - menu_dy ();
                           pixel2pos (m_ax_obj, pos_x1, pos_y1, x1, y1);
-                          Matrix xl (1,2,0);
-                          Matrix yl (1,2,0);
+                          Matrix xl (1, 2, 0);
+                          Matrix yl (1, 2, 0);
                           int dx = abs (m_pos_x - pos_x1);
                           int dy = abs (m_pos_y - pos_y1);
                           // Smallest zoom box must be 4 pixels square
@@ -2019,7 +2022,7 @@ private:
 
   static int curr_index;
 
-  typedef std::map<int, plot_window*> window_map;
+  typedef std::map<int, plot_window *> window_map;
 
   typedef window_map::iterator wm_iterator;;
 
@@ -2058,7 +2061,7 @@ private:
         idx2figprops (curr_index, fp);
 
         windows[curr_index++] = new plot_window (pos(0), pos(1), pos(2), pos(3),
-                                                 fp, internal);
+            fp, internal);
       }
   }
 
@@ -2197,7 +2200,7 @@ private:
   static int str2idx (const caseless_str& clstr)
   {
     int ind;
-    if (clstr.find (fltk_idx_header,0) == 0)
+    if (clstr.find (fltk_idx_header, 0) == 0)
       {
         std::istringstream istr (clstr.substr (fltk_idx_header.size ()));
         if (istr >> ind)
@@ -2230,7 +2233,7 @@ private:
 
   static int hnd2idx (double h)
   {
-    gh_manager& gh_mgr = octave::__get_gh_manager__ ("figure_manager::hnd2idx");
+    gh_manager& gh_mgr = octave::__get_gh_manager__ ();
 
     graphics_object fobj = gh_mgr.get_object (h);
 
@@ -2338,12 +2341,12 @@ public:
               {
               case base_properties::ID_VISIBLE:
                 figure_manager::toggle_window_visibility (ov.string_value (),
-                                                          fp.is_visible ());
+                    fp.is_visible ());
                 break;
 
               case figure::properties::ID_MENUBAR:
                 figure_manager::toggle_menubar_visibility
-                  (ov.string_value (), fp.menubar_is ("figure"));
+                (ov.string_value (), fp.menubar_is ("figure"));
                 break;
 
               case figure::properties::ID_CURRENTAXES:
@@ -2436,16 +2439,16 @@ public:
     return figure_manager::get_size (fh);
   }
 
-/*
-  double get_screen_resolution (void) const
-  {
-    // FLTK doesn't give this info.
-    return 72.0;
+  /*
+    double get_screen_resolution (void) const
+    {
+      // FLTK doesn't give this info.
+      return 72.0;
 
-    // FIXME: FLTK >= 1.3.0 could do this with Fl::screen_dpi (h, v, n)
-    // but do we need it?
-  }
-*/
+      // FIXME: FLTK >= 1.3.0 could do this with Fl::screen_dpi (h, v, n)
+      // but do we need it?
+    }
+  */
 
   Matrix get_screen_size (void) const
   {
@@ -2549,3 +2552,5 @@ Undocumented internal function.
 ## No test needed for internal helper function.
 %!assert (1)
 */
+
+OCTAVE_END_NAMESPACE(octave)
