@@ -1,26 +1,27 @@
-/*
-
-Copyright (C) 2004-2019 David Bateman
-Copyright (C) 1998-2004 Andy Adler
-Copyright (C) 2010 VZLU Prague
-
-This file is part of Octave.
-
-Octave is free software: you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Octave is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<https://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 1998-2023 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 // This file should not include config.h.  It is only included in other
 // C++ source files that should have included config.h before including
@@ -74,7 +75,7 @@ octave_base_sparse<T>::do_index_op (const octave_value_list& idx,
 
         case 1:
           {
-            idx_vector i = idx (0).index_vector ();
+            octave::idx_vector i = idx (0).index_vector ();
 
             retval = octave_value (matrix.index (i, resize_ok));
           }
@@ -82,10 +83,10 @@ octave_base_sparse<T>::do_index_op (const octave_value_list& idx,
 
         case 2:
           {
-            idx_vector i = idx (0).index_vector ();
+            octave::idx_vector i = idx (0).index_vector ();
 
             k = 1;
-            idx_vector j = idx (1).index_vector ();
+            octave::idx_vector j = idx (1).index_vector ();
 
             retval = octave_value (matrix.index (i, j, resize_ok));
           }
@@ -95,10 +96,10 @@ octave_base_sparse<T>::do_index_op (const octave_value_list& idx,
           error ("sparse indexing needs 1 or 2 indices");
         }
     }
-  catch (octave::index_exception& e)
+  catch (octave::index_exception& ie)
     {
       // Rethrow to allow more info to be reported later.
-      e.set_pos_if_unset (n_idx, k+1);
+      ie.set_pos_if_unset (n_idx, k+1);
       throw;
     }
 
@@ -178,59 +179,6 @@ octave_base_sparse<T>::subsasgn (const std::string& type,
   return retval;
 }
 
-template <typename T>
-void
-octave_base_sparse<T>::assign (const octave_value_list& idx, const T& rhs)
-{
-
-  octave_idx_type len = idx.length ();
-
-  // If we catch an indexing error in index_vector, we flag an error in
-  // index k.  Ensure it is the right value before each idx_vector call.
-  // Same variable as used in the for loop in the default case.
-
-  octave_idx_type k = 0;
-
-  try
-    {
-      switch (len)
-        {
-        case 1:
-          {
-            idx_vector i = idx (0).index_vector ();
-
-            matrix.assign (i, rhs);
-
-            break;
-          }
-
-        case 2:
-          {
-            idx_vector i = idx (0).index_vector ();
-
-            k = 1;
-            idx_vector j = idx (1).index_vector ();
-
-            matrix.assign (i, j, rhs);
-
-            break;
-          }
-
-        default:
-          error ("sparse indexing needs 1 or 2 indices");
-        }
-    }
-  catch (octave::index_exception& e)
-    {
-      // Rethrow to allow more info to be reported later.
-      e.set_pos_if_unset (len, k+1);
-      throw;
-    }
-
-  // Invalidate matrix type.
-  typ.invalidate_type ();
-}
-
 template <typename MT>
 void
 octave_base_sparse<MT>::delete_elements (const octave_value_list& idx)
@@ -249,7 +197,7 @@ octave_base_sparse<MT>::delete_elements (const octave_value_list& idx)
         {
         case 1:
           {
-            idx_vector i = idx (0).index_vector ();
+            octave::idx_vector i = idx (0).index_vector ();
 
             matrix.delete_elements (i);
 
@@ -258,10 +206,10 @@ octave_base_sparse<MT>::delete_elements (const octave_value_list& idx)
 
         case 2:
           {
-            idx_vector i = idx (0).index_vector ();
+            octave::idx_vector i = idx (0).index_vector ();
 
             k = 1;
-            idx_vector j = idx (1).index_vector ();
+            octave::idx_vector j = idx (1).index_vector ();
 
             matrix.delete_elements (i, j);
 
@@ -272,10 +220,10 @@ octave_base_sparse<MT>::delete_elements (const octave_value_list& idx)
           error ("sparse indexing needs 1 or 2 indices");
         }
     }
-  catch (octave::index_exception& e)
+  catch (octave::index_exception& ie)
     {
       // Rethrow to allow more info to be reported later.
-      e.set_pos_if_unset (len, k+1);
+      ie.set_pos_if_unset (len, k+1);
       throw;
     }
 
@@ -444,7 +392,7 @@ octave_base_sparse<MT>::edit_display (const float_display_format& fmt,
                                       octave_idx_type j) const
 {
   std::ostringstream buf;
-  octave_print_internal (buf, fmt, this->matrix(i,j));
+  octave_print_internal (buf, fmt, this->matrix(i, j));
   return buf.str ();
 }
 
@@ -501,7 +449,7 @@ octave_base_sparse<T>::fast_elem_extract (octave_idx_type n) const
   octave_idx_type i = n % nr;
   octave_idx_type j = n / nr;
 
-  return (i < nr && j < nc) ? octave_value (matrix(i,j)) : octave_value ();
+  return (i < nr && j < nc) ? octave_value (matrix(i, j)) : octave_value ();
 }
 
 template <typename T>
