@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2007-2022 The Octave Project Developers
+// Copyright (C) 2007-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -200,7 +200,7 @@ octave_class::octave_class (const octave_map& m, const std::string& id,
         }
     }
 
-  octave::symbol_table& symtab = octave::__get_symbol_table__ ("octave_class");
+  octave::symbol_table& symtab = octave::__get_symbol_table__ ();
 
   symtab.add_to_parent_map (id, m_parent_list);
 }
@@ -231,8 +231,7 @@ octave_class::get_current_method_class (void)
 
   if (nparents () > 0)
     {
-      octave::tree_evaluator& tw
-        = octave::__get_evaluator__ ("octave_class::get_current_method_class");
+      octave::tree_evaluator& tw = octave::__get_evaluator__ ();
 
       octave_function *fcn = tw.current_function ();
 
@@ -281,7 +280,7 @@ octave_class::break_closure_cycles (const std::shared_ptr<octave::stack_frame>&
 Cell
 octave_class::dotref (const octave_value_list& idx)
 {
-  assert (idx.length () == 1);
+  panic_if (idx.length () != 1);
 
   std::string method_class = get_current_method_class ();
 
@@ -313,8 +312,7 @@ octave_class::size (void)
 
   Matrix retval (1, 2, 1.0);
 
-  octave::symbol_table& symtab
-    = octave::__get_symbol_table__ ("octave_class::size");
+  octave::symbol_table& symtab = octave::__get_symbol_table__ ();
 
   octave_value meth = symtab.find_method ("size", class_name ());
 
@@ -354,8 +352,7 @@ octave_class::xnumel (const octave_value_list& idx)
   octave_idx_type retval = -1;
   const std::string cn = class_name ();
 
-  octave::symbol_table& symtab
-    = octave::__get_symbol_table__ ("octave_class::numel");
+  octave::symbol_table& symtab = octave::__get_symbol_table__ ();
 
   octave_value meth = symtab.find_method ("numel", cn);
 
@@ -410,7 +407,7 @@ octave_class::subsref (const std::string& type,
                 Cell t = tmp.index (idx.front ());
 
                 retval(0) = (t.numel () == 1 ? t(0)
-                                             : octave_value (t, true));
+                             : octave_value (t, true));
 
                 // We handled two index elements, so tell
                 // next_subsref to skip both of them.
@@ -450,8 +447,7 @@ octave_class::subsref (const std::string& type,
     }
   else
     {
-      octave::symbol_table& symtab
-        = octave::__get_symbol_table__ ("octave_class::subsref");
+      octave::symbol_table& symtab = octave::__get_symbol_table__ ();
 
       octave_value meth = symtab.find_method ("subsref", class_name ());
 
@@ -551,8 +547,7 @@ octave_class::subsasgn_common (const octave_value& obj,
 
   if (! (in_class_method () || called_from_builtin ()))
     {
-      octave::symbol_table& symtab
-        = octave::__get_symbol_table__ ("octave_class::subsasgn_common");
+      octave::symbol_table& symtab = octave::__get_symbol_table__ ();
 
       octave_value meth = symtab.find_method ("subsasgn", class_name ());
 
@@ -654,7 +649,7 @@ octave_class::subsasgn_common (const octave_value& obj,
 
                 octave_value_list key_idx = *++p;
 
-                assert (key_idx.length () == 1);
+                panic_if (key_idx.length () != 1);
 
                 std::string key = key_idx(0).xstring_value ("invalid index for class assignment");
 
@@ -692,7 +687,7 @@ octave_class::subsasgn_common (const octave_value& obj,
           {
             octave_value_list key_idx = idx.front ();
 
-            assert (key_idx.length () == 1);
+            panic_if (key_idx.length () != 1);
 
             std::string key = key_idx(0).string_value ();
 
@@ -747,7 +742,7 @@ octave_class::subsasgn_common (const octave_value& obj,
             auto p = idx.begin ();
             octave_value_list key_idx = *++p;
 
-            assert (key_idx.length () == 1);
+            panic_if (key_idx.length () != 1);
 
             std::string key = key_idx(0).xstring_value ("assignment to class element failed");
 
@@ -785,7 +780,7 @@ octave_class::subsasgn_common (const octave_value& obj,
       {
         octave_value_list key_idx = idx.front ();
 
-        assert (key_idx.length () == 1);
+        panic_if (key_idx.length () != 1);
 
         std::string key = key_idx(0).string_value ();
 
@@ -828,8 +823,7 @@ octave_class::subsasgn_common (const octave_value& obj,
 octave::idx_vector
 octave_class::index_vector (bool require_integers) const
 {
-  octave::symbol_table& symtab
-    = octave::__get_symbol_table__ ("octave_class::index_vector");
+  octave::symbol_table& symtab = octave::__get_symbol_table__ ();
 
   octave_value meth = symtab.find_method ("subsindex", class_name ());
 
@@ -877,8 +871,7 @@ octave_class::is_true (void) const
 {
   bool retval = false;
 
-  octave::symbol_table& symtab
-    = octave::__get_symbol_table__ ("octave_class::is_true");
+  octave::symbol_table& symtab = octave::__get_symbol_table__ ();
 
   octave_value meth = symtab.find_method ("logical", class_name ());
 
@@ -996,8 +989,7 @@ octave_class::string_vector_value (bool pad) const
 {
   string_vector retval;
 
-  octave::symbol_table& symtab
-    = octave::__get_symbol_table__ ("octave_class::string_vector_value");
+  octave::symbol_table& symtab = octave::__get_symbol_table__ ();
 
   octave_value meth = symtab.find_method ("char", class_name ());
 
@@ -1049,8 +1041,7 @@ octave_class::reconstruct_exemplar (void)
     retval = true;
   else
     {
-      octave::interpreter& interp
-        = octave::__get_interpreter__  ("octave_class::reconstruct_exemplar");
+      octave::interpreter& interp = octave::__get_interpreter__ ();
 
       octave::symbol_table& symtab = interp.get_symbol_table ();
 
@@ -1068,7 +1059,7 @@ octave_class::reconstruct_exemplar (void)
           // Something has gone terribly wrong if
           // symbol_table::find_method (c_name, c_name) does not return
           // a class constructor for the class c_name...
-          assert (have_ctor);
+          panic_unless (have_ctor);
         }
 
       if (have_ctor)
@@ -1174,7 +1165,7 @@ octave_class::save_ascii (std::ostream& os)
   os << "# classname: " << class_name () << "\n";
   octave_map m;
 
-  octave::load_path& lp = octave::__get_load_path__ ("octave_class::save_ascii");
+  octave::load_path& lp = octave::__get_load_path__ ();
 
   if (lp.find_method (class_name (), "saveobj") != "")
     {
@@ -1232,7 +1223,8 @@ octave_class::load_ascii (std::istream& is)
           if (! is)
             break;
 
-          Cell tcell = (t2.iscell () ? t2.xcell_value ("load: internal error loading class elements") : Cell (t2));
+          Cell tcell = (t2.iscell () ? t2.xcell_value ("load: internal error loading class elements") : Cell (
+                          t2));
 
           m.assign (nm, tcell);
         }
@@ -1248,7 +1240,7 @@ octave_class::load_ascii (std::istream& is)
       if (! reconstruct_parents ())
         warning ("load: unable to reconstruct object inheritance");
 
-      octave::load_path& lp = octave::__get_load_path__ ("octave_class::load_ascii");
+      octave::load_path& lp = octave::__get_load_path__ ();
 
       if (lp.find_method (classname, "loadobj") != "")
         {
@@ -1279,7 +1271,7 @@ octave_class::save_binary (std::ostream& os, bool save_as_floats)
 
   octave_map m;
 
-  octave::load_path& lp = octave::__get_load_path__ ("octave_class::save_binary");
+  octave::load_path& lp = octave::__get_load_path__ ();
 
   if (lp.find_method (class_name (), "saveobj") != "")
     {
@@ -1356,7 +1348,8 @@ octave_class::load_binary (std::istream& is, bool swap,
           if (! is)
             break;
 
-          Cell tcell = (t2.iscell () ? t2.xcell_value ("load: internal error loading class elements") : Cell (t2));
+          Cell tcell = (t2.iscell () ? t2.xcell_value ("load: internal error loading class elements") : Cell (
+                          t2));
 
           m.assign (nm, tcell);
         }
@@ -1368,7 +1361,7 @@ octave_class::load_binary (std::istream& is, bool swap,
           if (! reconstruct_parents ())
             warning ("load: unable to reconstruct object inheritance");
 
-          octave::load_path& lp = octave::__get_load_path__ ("octave_class::load_binary");
+          octave::load_path& lp = octave::__get_load_path__ ();
 
           if (lp.find_method (c_name, "loadobj") != "")
             {
@@ -1407,7 +1400,7 @@ octave_class::save_hdf5 (octave_hdf5_id loc_id, const char *name,
   octave_map m;
   octave_map::iterator i;
 
-  octave::load_path& lp = octave::__get_load_path__ ("octave_class::save_hdf5");
+  octave::load_path& lp = octave::__get_load_path__ ();
 
 #if defined (HAVE_HDF5_18)
   group_hid = H5Gcreate (loc_id, name, octave_H5P_DEFAULT, octave_H5P_DEFAULT,
@@ -1604,7 +1597,8 @@ octave_class::load_hdf5 (octave_hdf5_id loc_id, const char *name)
     {
       octave_value t2 = dsub.tc;
 
-      Cell tcell = (t2.iscell () ? t2.xcell_value ("load: internal error loading class elements") : Cell (t2));
+      Cell tcell = (t2.iscell () ? t2.xcell_value ("load: internal error loading class elements") : Cell (
+                      t2));
 
       m.assign (dsub.name, tcell);
 
@@ -1617,7 +1611,7 @@ octave_class::load_hdf5 (octave_hdf5_id loc_id, const char *name)
       if (! reconstruct_parents ())
         warning ("load: unable to reconstruct object inheritance");
 
-      octave::load_path& lp = octave::__get_load_path__ ("octave_class::load_hdf5");
+      octave::load_path& lp = octave::__get_load_path__ ();
 
       if (lp.find_method (c_name, "loadobj") != "")
         {
@@ -1655,8 +1649,7 @@ octave_class::as_mxArray (bool) const
 bool
 octave_class::in_class_method (void)
 {
-  octave::tree_evaluator& tw
-    = octave::__get_evaluator__ ("octave_class::in_class_method");
+  octave::tree_evaluator& tw = octave::__get_evaluator__ ();
 
   octave_function *fcn = tw.current_function ();
 
@@ -1722,18 +1715,18 @@ octave_class::exemplar_info::compare (const octave_value& obj) const
   return true;
 }
 
-OCTAVE_NAMESPACE_BEGIN
+OCTAVE_BEGIN_NAMESPACE(octave)
 
 DEFMETHOD (class, interp, args, ,
            doc: /* -*- texinfo -*-
 @deftypefn  {} {@var{classname} =} class (@var{obj})
-@deftypefnx {} {} class (@var{s}, @var{id})
-@deftypefnx {} {} class (@var{s}, @var{id}, @var{p}, @dots{})
-Return the class of the object @var{obj}, or create a class with
-fields from structure @var{s} and name (string) @var{id}.
+@deftypefnx {} {@var{cls} =} class (@var{s}, @var{classname})
+@deftypefnx {} {@var{cls} =} class (@var{s}, @var{classname}, @var{parent1}, @dots{})
+Return the class of the object @var{obj}, or create a class with fields from
+structure @var{s} and name (string) @var{classname}.
 
-Additional arguments name a list of parent classes from which the new class
-is derived.
+Additional arguments name a list of parent classes from which the new class is
+derived.
 @seealso{typeinfo, isa}
 @end deftypefn */)
 {
@@ -1802,7 +1795,7 @@ is derived.
 
 DEFUN (isa, args, ,
        doc: /* -*- texinfo -*-
-@deftypefn {} {} isa (@var{obj}, @var{classname})
+@deftypefn {} {@var{tf} =} isa (@var{obj}, @var{classname})
 Return true if @var{obj} is an object from the class @var{classname}.
 
 @var{classname} may also be one of the following class categories:
@@ -1831,7 +1824,8 @@ belongs to.
 
   octave_value obj = args(0);  // not const because of find_parent_class ()
   std::string obj_cls = obj.class_name ();
-  Array<std::string> clsnames = args(1).xcellstr_value ("isa: CLASSNAME must be a string or cell array of strings");
+  Array<std::string> clsnames = args(
+                                  1).xcellstr_value ("isa: CLASSNAME must be a string or cell array of strings");
 
   boolNDArray matches (clsnames.dims (), false);
 
@@ -1911,7 +1905,7 @@ belongs to.
 
 DEFUN (__parent_classes__, args, ,
        doc: /* -*- texinfo -*-
-@deftypefn {} {} __parent_classes__ (@var{x})
+@deftypefn {} {@var{Ccls} =} __parent_classes__ (@var{x})
 Undocumented internal function.
 @end deftypefn */)
 {
@@ -1928,7 +1922,7 @@ Undocumented internal function.
 
 DEFUN (isobject, args, ,
        doc: /* -*- texinfo -*-
-@deftypefn {} {} isobject (@var{x})
+@deftypefn {} {@var{tf} =} isobject (@var{x})
 Return true if @var{x} is a class object.
 @seealso{class, typeinfo, isa, ismethod, isprop}
 @end deftypefn */)
@@ -2038,7 +2032,7 @@ may @emph{only} be called from a class constructor.
                inf_class.c_str (), sup_class.c_str ());
     }
 
-  return octave_value();
+  return ovl ();
 }
 
 // The following classes allow us to define "inline" function objects as
@@ -2148,15 +2142,12 @@ octave_inline_fcn::execute (tree_evaluator& tw, int nargout,
 
 DEFUN (__inline_ctor__, args, ,
        doc: /* -*- texinfo -*-
-@deftypefn {} {} __inline_ctor__ (@var{prop_struct})
-Internal function.
-
-Implements final construction for inline objects.
+@deftypefn {} {@var{inline_obj} =} __inline_ctor__ (@var{prop_struct})
+Implement final construction for inline objects.
 @end deftypefn */)
 {
   // Input validation has already been done in input.m.
-
   return octave_value (new octave_inline (args(0).map_value ()));
 }
 
-OCTAVE_NAMESPACE_END
+OCTAVE_END_NAMESPACE(octave)
