@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1996-2021 The Octave Project Developers
+// Copyright (C) 1996-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -41,6 +41,8 @@
 #include "xdiv.h"
 #include "xpow.h"
 
+OCTAVE_BEGIN_NAMESPACE(octave)
+
 // scalar unary ops.
 
 DEFUNOP (not, scalar)
@@ -158,3 +160,5 @@ install_s_s_ops (octave::type_info& ti)
   INSTALL_ASSIGNCONV_TI (ti, octave_scalar, octave_null_str, octave_matrix);
   INSTALL_ASSIGNCONV_TI (ti, octave_scalar, octave_null_sq_str, octave_matrix);
 }
+
+OCTAVE_END_NAMESPACE(octave)
