@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2013-2022 The Octave Project Developers
+// Copyright (C) 2013-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -32,58 +32,59 @@
 #include "error.h"
 #include "pt-array-list.h"
 
-namespace octave
+OCTAVE_BEGIN_NAMESPACE(octave)
+
+tree_array_list::~tree_array_list (void)
 {
-  tree_array_list::~tree_array_list (void)
-  {
-    while (! empty ())
-      {
-        auto p = begin ();
-        delete *p;
-        erase (p);
-      }
-  }
-
-  bool
-  tree_array_list::all_elements_are_constant (void) const
-  {
-    for (const tree_argument_list *elt : *this)
-      {
-        octave_quit ();
-
-        if (! elt->all_elements_are_constant ())
-          return false;
-      }
-
-    return true;
-  }
-
-  void
-  tree_array_list::copy_base (const tree_array_list& array_list)
-  {
-    tree_expression::copy_base (array_list);
-  }
-
-  void
-  tree_array_list::copy_base (const tree_array_list& array_list,
-                              symbol_scope& scope)
-  {
-    for (const tree_argument_list *elt : array_list)
-      append (elt ? elt->dup (scope) : nullptr);
-
-    copy_base (*this);
-  }
-
-  tree_expression *
-  tree_array_list::dup (symbol_scope&) const
-  {
-    panic_impossible ();
-    return nullptr;
-  }
-
-  void
-  tree_array_list::accept (tree_walker&)
-  {
-    panic_impossible ();
-  }
+  while (! empty ())
+    {
+      auto p = begin ();
+      delete *p;
+      erase (p);
+    }
 }
+
+bool
+tree_array_list::all_elements_are_constant (void) const
+{
+  for (const tree_argument_list *elt : *this)
+    {
+      octave_quit ();
+
+      if (! elt->all_elements_are_constant ())
+        return false;
+    }
+
+  return true;
+}
+
+void
+tree_array_list::copy_base (const tree_array_list& array_list)
+{
+  tree_expression::copy_base (array_list);
+}
+
+void
+tree_array_list::copy_base (const tree_array_list& array_list,
+                            symbol_scope& scope)
+{
+  for (const tree_argument_list *elt : array_list)
+    append (elt ? elt->dup (scope) : nullptr);
+
+  copy_base (*this);
+}
+
+tree_expression *
+tree_array_list::dup (symbol_scope&) const
+{
+  panic_impossible ();
+  return nullptr;
+}
+
+void
+tree_array_list::accept (tree_walker&)
+{
+  panic_impossible ();
+}
+
+OCTAVE_END_NAMESPACE(octave)
