@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1996-2021 The Octave Project Developers
+// Copyright (C) 1996-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -151,7 +151,7 @@ not returning a value from a function declared to return something.
           need to be changed for others.  */
 
 typedef union
-{
+  {
   const char *const_ptr;
   char *ptr;
   struct
@@ -336,20 +336,21 @@ F77_FUNC (xstopx, XSTOPX) (F77_CONST_CHAR_ARG_DECL
 
 #if defined (__cplusplus)
 
-namespace octave
-{
-  inline F77_INT
-  to_f77_int (octave_idx_type x)
-  {
-    if (x < std::numeric_limits<F77_INT>::min ()
-        || x > std::numeric_limits<F77_INT>::max ())
-      (*current_liboctave_error_handler)
-        ("integer dimension or index out of range for Fortran INTEGER type");
+OCTAVE_BEGIN_NAMESPACE(octave)
 
-    return static_cast<F77_INT> (x);
-  }
+inline F77_INT
+to_f77_int (octave_idx_type x)
+{
+  if (x < std::numeric_limits<F77_INT>::min ()
+      || x > std::numeric_limits<F77_INT>::max ())
+    (*current_liboctave_error_handler)
+      ("integer dimension or index out of range for Fortran INTEGER type");
+
+  return static_cast<F77_INT> (x);
 }
 
+OCTAVE_END_NAMESPACE(octave)
+
 #endif
 
 #if defined (__cplusplus)
