@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2016-2021 The Octave Project Developers
+// Copyright (C) 2016-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -30,7 +30,8 @@
 extern "C" {
 #endif
 
-extern char * octave_canonicalize_file_name_wrapper (const char *name);
+extern OCTAVE_API char *
+octave_canonicalize_file_name_wrapper (const char *name);
 
 #if defined __cplusplus
 }
