@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 2008-2022 The Octave Project Developers
+## Copyright (C) 2008-2023 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -24,10 +24,10 @@
 ########################################################################
 
 ## -*- texinfo -*-
-## @deftypefn {} {} idivide (@var{x}, @var{y}, @var{op})
+## @deftypefn {} {@var{C} =} idivide (@var{A}, @var{B}, @var{op})
 ## Integer division with different rounding rules.
 ##
-## The standard behavior of integer division such as @code{@var{a} ./ @var{b}}
+## The standard behavior of integer division such as @code{@var{A} ./ @var{B}}
 ## is to round the result to the nearest integer.  This is not always the
 ## desired behavior and @code{idivide} permits integer element-by-element
 ## division to be performed with different treatment for the fractional
@@ -36,19 +36,19 @@
 ##
 ## @table @asis
 ## @item @qcode{"fix"}
-## Calculate @code{@var{a} ./ @var{b}} with the fractional part rounded
+## Calculate @code{@var{A} ./ @var{B}} with the fractional part rounded
 ## towards zero.
 ##
 ## @item @qcode{"round"}
-## Calculate @code{@var{a} ./ @var{b}} with the fractional part rounded
+## Calculate @code{@var{A} ./ @var{B}} with the fractional part rounded
 ## towards the nearest integer.
 ##
 ## @item @qcode{"floor"}
-## Calculate @code{@var{a} ./ @var{b}} with the fractional part rounded
+## Calculate @code{@var{A} ./ @var{B}} with the fractional part rounded
 ## towards negative infinity.
 ##
 ## @item @qcode{"ceil"}
-## Calculate @code{@var{a} ./ @var{b}} with the fractional part rounded
+## Calculate @code{@var{A} ./ @var{B}} with the fractional part rounded
 ## towards positive infinity.
 ## @end table
 ##
@@ -69,10 +69,10 @@
 ## @end group
 ## @end example
 ##
-## @seealso{ldivide, rdivide}
+## @seealso{ceil, floor, fix, round, ldivide, rdivide}
 ## @end deftypefn
 
-function z = idivide (x, y, op)
+function C = idivide (A, B, op)
 
   if (nargin < 2)
     print_usage ();
@@ -84,33 +84,76 @@ function z = idivide (x, y, op)
     op = tolower (op);
   endif
 
-  if (isfloat (x))
-    if (isinteger (y))
-      typ = class (y);
-    else
-      error ("idivide: at least one input (X or Y) must be an integer type");
-    endif
-  elseif (isfloat (y))
-    if (isinteger (x))
-      typ = class (x);
-    else
-      error ("idivide: at least one input (X or Y) must be an integer type");
-    endif
-  else
-    typ = class (x);
-    if (! strcmp (typ, class (y)))
-      error ("idivide: integer type of X (%s) must match integer type of Y (%s)", typ, class (y));
-    endif
+  if (! isinteger (A) && ! isinteger (B))
+    error ("idivide: at least one input (A or B) must be an integer type");
+  elseif (isinteger (A) && isinteger (B) && ! strcmp (class (A), class (B)))
+    error ("idivide: integer type of A (%s) must match integer type of B (%s)",
+           class (A), class (B));
   endif
 
+  C = A ./ B;
   if (strcmp (op, "fix"))
-    z = cast (fix (double (x) ./ double (y)), typ);
+    ## The following is an optimized version of `C -= (C .* B > A) .* sign (B)`.
+    if (isscalar (B))
+      if (B > 0)
+        C -= (C * B > A);
+      else
+        C += (C * B > A);
+      endif
+    else
+      y_sel = (B > 0);
+      if (isscalar (A))
+        C(y_sel) -= (C(y_sel) .* B(y_sel) > A);
+        y_sel = ! y_sel;
+        C(y_sel) += (C(y_sel) .* B(y_sel) > A);
+      else
+        C(y_sel) -= (C(y_sel) .* B(y_sel) > A(y_sel));
+        y_sel = ! y_sel;
+        C(y_sel) += (C(y_sel) .* B(y_sel) > A(y_sel));
+      endif
+    endif
   elseif (strcmp (op, "round"))
-    z = x ./ y;
+    return;
   elseif (strcmp (op, "floor"))
-    z = cast (floor (double (x) ./ double (y)), typ);
+    ## The following is an optimized version of `C -= (C .* abs (B) > sign (B) .* A)`.
+    if (isscalar (B))
+      if (B > 0)
+        C -= (C * B > A);
+      else
+        C -= (C * B < A);
+      endif
+    else
+      y_sel = (B > 0);
+      if (isscalar (A))
+        C(y_sel) -= (C(y_sel) .* B(y_sel) > A);
+        y_sel = ! y_sel;
+        C(y_sel) -= (C(y_sel) .* B(y_sel) < A);
+      else
+        C(y_sel) -= (C(y_sel) .* B(y_sel) > A(y_sel));
+        y_sel = ! y_sel;
+        C(y_sel) -= (C(y_sel) .* B(y_sel) < A(y_sel));
+      endif
+    endif
   elseif (strcmp (op, "ceil"))
-    z = cast (ceil (double (x) ./ double (y)), typ);
+    ## The following is an optimized version of `C += (C .* abs (B) < sign (B) .* A)`.
+    if (isscalar (B))
+      if (B > 0)
+        C += (C * B < A);
+      else
+        C += (C * B > A);
+      endif
+    else
+      y_sel = (B > 0);
+      if (isscalar (A))
+        C(y_sel) += (C(y_sel) .* B(y_sel) < A);
+        y_sel = ! y_sel;
+        C(y_sel) += (C(y_sel) .* B(y_sel) > A);
+      else
+        C(y_sel) += (C(y_sel) .* B(y_sel) < A(y_sel));
+        y_sel = ! y_sel;
+        C(y_sel) += (C(y_sel) .* B(y_sel) > A(y_sel));
+      endif
+    endif
   else
     error ('idivide: unrecognized rounding type "%s"', op);
   endif
@@ -139,10 +182,24 @@ endfunction
 %!assert (idivide (a, bf, "ceil"), int8 ([0, 1]))
 %!assert (idivide (a, bf, "round"), int8 ([-1, 1]))
 
+%!shared c, d
+%! c = int64 (4e16);
+%! d = int64 ([-2e8, 2e8]);
+
+%!assert <*61319> (idivide (c, d + int64 (1)), d + int64 ([-1, -1]))
+%!assert <*61319> (idivide (c, d + int64 (1), "floor"), d + int64 ([-2, -1]))
+%!assert <*61319> (idivide (c, d + int64 (1), "ceil"), d + int64 ([-1, 0]))
+%!assert <*61319> (idivide (c, d + int64 (1), "round"), d + int64 ([-1, -1]))
+
+%!assert <*61319> (idivide (c + int64 (1), d), d)
+%!assert <*61319> (idivide (c + int64 (1), d, "floor"), d + int64 ([-1, 0]))
+%!assert <*61319> (idivide (c + int64 (1), d, "ceil"), d + int64 ([0, 1]))
+%!assert <*61319> (idivide (c + int64 (1), d, "round"), d)
+
 ## Test input validation
 %!error idivide (uint8 (1))
 %!error idivide (uint8 (1), 2, 3)
 %!error <at least one input> idivide (1, 2)
 %!error <at least one input> idivide ({1}, 2)
-%!error <X \(int8\) must match.* Y \(uint8\)> idivide (int8 (1), uint8 (2))
+%!error <A \(int8\) must match.* B \(uint8\)> idivide (int8 (1), uint8 (2))
 %!error <unrecognized rounding type "foo"> idivide (int8 (1), 2, "foo")
