@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 1993-2021 The Octave Project Developers
+## Copyright (C) 1993-2023 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -24,9 +24,9 @@
 ########################################################################
 
 ## -*- texinfo -*-
-## @deftypefn  {} {} num2str (@var{x})
-## @deftypefnx {} {} num2str (@var{x}, @var{precision})
-## @deftypefnx {} {} num2str (@var{x}, @var{format})
+## @deftypefn  {} {@var{str} =} num2str (@var{x})
+## @deftypefnx {} {@var{str} =} num2str (@var{x}, @var{precision})
+## @deftypefnx {} {@var{str} =} num2str (@var{x}, @var{format})
 ## Convert a number (or array) to a string (or a character array).
 ##
 ## The optional second argument may either give the number of significant
@@ -78,24 +78,28 @@
 ## @seealso{sprintf, int2str, mat2str}
 ## @end deftypefn
 
-function retval = num2str (x, arg)
+function str = num2str (x, arg)
 
-  if (nargin != 1 && nargin != 2)
+  if (nargin < 1)
     print_usage ();
   elseif (! (isnumeric (x) || islogical (x) || ischar (x)))
     error ("num2str: X must be a numeric, logical, or character array");
   endif
 
   if (ischar (x))
-    retval = x;
+    str = x;
   elseif (isempty (x))
-    retval = "";
+    str = "";
   elseif (isreal (x))
     if (nargin == 2)
       if (ischar (arg))
         fmt = arg;
       elseif (isnumeric (arg) && isscalar (arg) && arg >= 0 && arg == fix (arg))
-        fmt = sprintf ("%%%d.%dg", arg+7, arg);
+        if (isfloat (x))
+          fmt = sprintf ("%%%d.%dg", arg+7, arg);
+        else
+          fmt = sprintf ("%%%dd", arg);
+        endif
       else
         error ("num2str: PRECISION must be a scalar integer >= 0");
       endif
@@ -119,7 +123,11 @@ function retval = num2str (x, arg)
           if (any (! valid))
             ndgt = max (ndgt, 5);     # Allow space for Inf/NaN
           endif
-          fmt = sprintf ("%%%d.0f", ndgt);
+          if (isfloat (x))
+            fmt = sprintf ("%%%d.0f", ndgt);
+          else
+            fmt = sprintf ("%%%dd", ndgt);
+          endif
         endif
       else
         ## Logical input
@@ -130,11 +138,12 @@ function retval = num2str (x, arg)
     nd = ndims (x);
     nc = columns (x) * (nd - 1);    # ND-arrays are expanded in columns
     x  = permute (x, [2, 3:nd, 1]);
-    if (! (sum (fmt == "%") > 1 || any (strcmp (fmt, {"%s", "%c"}))))
+    if (! (sum (strrep (fmt, "%%", "") == "%") > 1
+           || any (strcmp (fmt, {"%s", "%c"}))))
       fmt = [deblank(repmat (fmt, 1, nc)), "\n"];
     endif
     strtmp = sprintf (fmt, x);
-    retval = strtrim (char (ostrsplit (strtmp, "\n", true)));
+    str = strtrim (char (ostrsplit (strtmp, "\n", true)));
   else   # Complex matrix input
     if (nargin == 2)
       if (ischar (arg))
@@ -186,7 +195,7 @@ function retval = num2str (x, arg)
     tmp = regexprep (tmp, " +i\n", "i\n");
     tmp = regexprep (tmp, "( +)i", "i$1");
 
-    retval = strtrim (char (ostrsplit (tmp(1:end-1), "\n")));
+    str = strtrim (char (ostrsplit (tmp(1:end-1), "\n")));
   endif
 
 endfunction
@@ -211,14 +220,16 @@ endfunction
 %!assert (num2str ([inf -inf]), "Inf -Inf")
 %!assert (num2str ([inf NaN -inf]), "Inf  NaN -Inf")
 %!assert (num2str ([complex(Inf,0), complex(0,-Inf)]), "Inf+0i   0-Infi")
-%!assert (num2str (complex(Inf,1)), "Inf+1i")
-%!assert (num2str (complex(1,Inf)), "1+Infi")
+%!assert (num2str (complex (Inf,1)), "Inf+1i")
+%!assert (num2str (complex (1,Inf)), "1+Infi")
 %!assert (num2str (nan), "NaN")
 %!assert (num2str (complex (NaN, 1)), "NaN+1i")
 %!assert (num2str (complex (1, NaN)), "1+NaNi")
 %!assert (num2str (NA), "NA")
 %!assert (num2str (complex (NA, 1)), "NA+1i")
 %!assert (num2str (complex (1, NA)), "1+NAi")
+%!assert (num2str (int64 (-flintmax ()) - 1), "-9007199254740993")
+%!assert (num2str (int64 (-flintmax ()) - 1, 18), "-9007199254740993")
 
 ## ND-arrays are concatenated in columns
 %!shared m, x
@@ -249,7 +260,7 @@ endfunction
 %!assert <*36133> (num2str (1e15), "1000000000000000")
 %!assert <*36133> (num2str (1e16), "1e+16")
 ## Even exact integers in IEEE notation should use exponential notation
-%!assert <*36133> (num2str(2^512), "1.34078079299426e+154")
+%!assert <*36133> (num2str (2^512), "1.34078079299426e+154")
 ## Mixed integer/floating point arrays
 %!assert <*36133> (num2str ([2.1, 1e23, pi]),
 %!                 "2.1  9.999999999999999e+22      3.141592653589793")
@@ -265,8 +276,7 @@ endfunction
 %!assert <*45174> (num2str ([65 66 67], "%s"), "ABC")
 
 ## Test input validation
-%!error num2str ()
-%!error num2str (1, 2, 3)
+%!error <Invalid call> num2str ()
 %!error <X must be a numeric> num2str ({1})
 %!error <PRECISION must be a scalar integer .= 0> num2str (1, {1})
 %!error <PRECISION must be a scalar integer .= 0> num2str (1, ones (2))
