@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 2000-2020 The Octave Project Developers
+## Copyright (C) 2000-2023 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -67,7 +67,7 @@
 
 function z = trapz (x, y, dim)
 
-  if (nargin < 1) || (nargin > 3)
+  if (nargin < 1)
     print_usage ();
   endif
 
@@ -153,8 +153,7 @@ endfunction
 %!assert <*54277> (trapz (ones (3,1), 2), zeros (3,1))
 
 ## Test input validation
-%!error trapz ()
-%!error trapz (1,2,3,4)
+%!error <Invalid call> trapz ()
 %!error <DIM must be an integer> trapz (1, 2, [1 2])
 %!error <DIM must be an integer> trapz (1, 2, 1.5)
 %!error <DIM must be .* a valid dimension> trapz (1, 2, 0)
