@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 2005-2022 The Octave Project Developers
+## Copyright (C) 2005-2023 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -168,21 +168,24 @@
 ##
 ## Options for the install command and the names of individual packages to be
 ## checked for updates may be specified as a list following the update
-## command. If the @option{-local} or @option{-global} option is specified,
+## command.  If the @option{-local} or @option{-global} option is specified,
 ## @code{pkg update} limits the update check to the local or global installed
 ## packages, and installs updates in that same context.  For example,
 ##
 ## Update all packages:
+##
 ## @example
 ## pkg update
 ## @end example
 ##
 ## Update all local packages:
+##
 ## @example
 ## pkg update -local
 ## @end example
 ##
 ## Update certain packages, ignore dependencies, max verbosity:
+##
 ## @example
 ## pkg update -verbose -nodeps image signal geometry
 ## @end example
@@ -534,6 +537,10 @@ function [local_packages, global_packages] = pkg (varargin)
         if (octave_forge)
           [urls, local_files] = cellfun ("get_forge_download", files,
                                          "uniformoutput", false);
+          if (verbose)
+            fprintf ("downloading tarball(s) from:%s\n", ...
+                     sprintf ("\n- %s", urls{:}));
+          endif
           [files, succ] = cellfun ("urlwrite", urls, local_files,
                                    "uniformoutput", false);
           succ = [succ{:}];
@@ -753,7 +760,7 @@ function [local_packages, global_packages] = pkg (varargin)
       localflag = any (strcmp (varargin, "-local"));
       if (globalflag || localflag)
         if (globalflag && localflag)
-          error ("pkg: cannot specify both global and local options.")
+          error ("pkg: cannot specify both global and local options.");
         elseif (globalflag)
           [~, installed_pkgs_lst] = installed_packages (local_list, global_list);
         else
