@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 2017-2021 The Octave Project Developers
+## Copyright (C) 2017-2023 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -24,7 +24,7 @@
 ########################################################################
 
 ## -*- texinfo -*-
-## @deftypefn  {} {@var{tickval} =} xticklabels
+## @deftypefn  {} {@var{labels} =} xticklabels
 ## @deftypefnx {} {@var{mode} =} xticklabels ("mode")
 ## @deftypefnx {} {} xticklabels (@var{tickval})
 ## @deftypefnx {} {} xticklabels ("auto")
@@ -56,17 +56,17 @@
 ## @seealso{xticks, yticklabels, zticklabels, get, set}
 ## @end deftypefn
 
-function retval = xticklabels (varargin)
+function labels = xticklabels (varargin)
 
   hax = [];
   switch (nargin)
     case 0
-      retval = get (gca , "xticklabel");  # will error if no xticklabel exists.
+      labels = get (gca , "xticklabel");  # will error if no xticklabel exists.
       return;
 
     case 1
       if (isaxes (varargin{1}))
-        retval = get (varargin{1}, "xticklabel");
+        labels = get (varargin{1}, "xticklabel");
         return;
       else
         arg = varargin{1};
@@ -102,7 +102,7 @@ function retval = xticklabels (varargin)
 
     endif
 
-    ## Convert any numeric elements to characters, make it a 1D cell array.
+    ## Convert any numeric elements to characters, make it a 1-D cell array.
     arg = cellfun (@num2str, arg, "UniformOutput", false)(:);
 
     ## Pad with blank cell entries if needed.
@@ -117,7 +117,7 @@ function retval = xticklabels (varargin)
     arg = tolower (arg);
     switch (arg)
       case "mode"
-        retval = get (hax, "xticklabelmode");
+        labels = get (hax, "xticklabelmode");
 
       case {"auto", "manual"}
         if (nargout > 0)
@@ -142,7 +142,7 @@ endfunction
 %! hf = figure ("visible", "off");
 %! unwind_protect
 %!   set (gca, "xticklabelmode", "auto");
-%!   hax = gca;
+%!   hax = gca ();
 %!   vals1 = xticklabels;
 %!   assert (xticklabels (hax), vals1);
 %!   mode1 = xticklabels ("mode");
@@ -164,7 +164,7 @@ endfunction
 %!test
 %! hf = figure ("visible", "off");
 %! unwind_protect
-%!   hax = gca;
+%!   hax = gca ();
 %!   fail ("xticklabels (-1, {})", "HAX must be a handle to an axes");
 %!   fail ("tmp = xticklabels (hax, {'A','B'})", "too many output arguments");
 %!   fail ("tmp = xticklabels (hax, [0, 1])", "too many output arguments");
