@@ -1,4 +1,9 @@
-## Copyright (C) 2005-2019 Paul Kienzle
+########################################################################
+##
+## Copyright (C) 2005-2023 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -15,19 +20,21 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
-## @deftypefn  {} {} fplot (@var{fn})
-## @deftypefnx {} {} fplot (@var{fn}, @var{limits})
+## @deftypefn  {} {} fplot (@var{fcn})
+## @deftypefnx {} {} fplot (@var{fcn}, @var{limits})
 ## @deftypefnx {} {} fplot (@dots{}, @var{tol})
 ## @deftypefnx {} {} fplot (@dots{}, @var{n})
 ## @deftypefnx {} {} fplot (@dots{}, @var{fmt})
 ## @deftypefnx {} {} fplot (@dots{}, @var{property}, @var{value}, @dots{})
 ## @deftypefnx {} {} fplot (@var{hax}, @dots{})
 ## @deftypefnx {} {[@var{x}, @var{y}] =} fplot (@dots{})
-## Plot a function @var{fn} within the range defined by @var{limits}.
+## Plot a function @var{fcn} within the range defined by @var{limits}.
 ##
-## @var{fn} is a function handle, inline function, or string containing the
+## @var{fcn} is a function handle, inline function, or string containing the
 ## name of the function to evaluate.
 ##
 ## The limits of the plot are of the form @w{@code{[@var{xlo}, @var{xhi}]}} or
@@ -52,6 +59,9 @@
 ## in pairs.  These arguments are applied to the line objects drawn by
 ## @code{plot}.
 ##
+## The full list of line properties is documented at
+## @ref{Line Properties}.
+##
 ## If the first argument @var{hax} is an axes handle, then plot into this axes,
 ## rather than the current axes returned by @code{gca}.
 ##
@@ -76,11 +86,9 @@
 ##
 ## @code{fplot} performance is better when the function accepts and returns a
 ## vector argument.  Consider this when writing user-defined functions and use
-## element-by-element operators such as @code{.*}, @code{./}, etc.  See the
-## function @code{vectorize} for potentially converting inline or anonymous
-## functions to vectorized versions.
+## element-by-element operators such as @code{.*}, @code{./}, etc.
 ##
-## @seealso{ezplot, plot, vectorize}
+## @seealso{ezplot, plot}
 ## @end deftypefn
 
 function [X, Y] = fplot (varargin)
@@ -91,19 +99,23 @@ function [X, Y] = fplot (varargin)
     print_usage ();
   endif
 
-  fn = varargin{1};
-  if (strcmp (typeinfo (fn), "inline function"))
-    fn = vectorize (fn);
-    nam = formula (fn);
-  elseif (is_function_handle (fn))
-    nam = func2str (fn);
-  elseif (all (isalnum (fn)))
-    nam = fn;
-  elseif (ischar (fn))
-    fn = vectorize (inline (fn));
-    nam = formula (fn);
+  fcn = varargin{1};
+  if (isa (fcn, "inline"))
+    ## Don't warn about intentional use of inline functions (Bug #62682)
+    warning ("off", "Octave:legacy-function", "local");
+    fcn = vectorize (inline (fcn));
+    nam = formula (fcn);
+  elseif (is_function_handle (fcn))
+    nam = func2str (fcn);
+  elseif (all (isalnum (fcn)))
+    nam = fcn;
+  elseif (ischar (fcn))
+    ## Don't warn about intentional use of inline functions (Bug #62682)
+    warning ("off", "Octave:legacy-function", "local");
+    fcn = vectorize (inline (fcn));
+    nam = formula (fcn);
   else
-    error ("fplot: FN must be a function handle, inline function, or string");
+    error ("fplot: FCN must be a function handle, inline function, or string");
   endif
 
   if (nargin > 1 && isnumeric (varargin{2}))
@@ -120,6 +132,7 @@ function [X, Y] = fplot (varargin)
   n = 5;
   tol = 2e-3;
   fmt = {};
+  prop_vals = {};
   while (i <= numel (varargin))
     arg = varargin{i};
     if (ischar (arg))
@@ -130,7 +143,7 @@ function [X, Y] = fplot (varargin)
         if (i == numel (varargin))
           error ("fplot: bad input in position %d", i);
         endif
-        fmt(end+(1:2)) = varargin([i, i+1]);
+        prop_vals(end+(1:2)) = varargin([i, i+1]);
         i++;  # Skip PROPERTY.
       endif
     elseif (isnumeric (arg) && isscalar (arg) && arg > 0)
@@ -154,21 +167,21 @@ function [X, Y] = fplot (varargin)
   endif
 
   try
-    y0 = feval (fn, x0);
+    y0 = feval (fcn, x0);
     if (isscalar (y0))
-      warning ("fplot: FN is not a vectorized function which reduces performance");
-      fn = @(x) arrayfun (fn, x);  # Create a new fn that accepts vectors
-      y0 = feval (fn, x0);
+      warning ("fplot: FCN is not a vectorized function which reduces performance");
+      fcn = @(x) arrayfun (fcn, x);  # Create a new fcn that accepts vectors
+      y0 = feval (fcn, x0);
     endif
   catch
     ## feval failed, maybe it is because the function is not vectorized?
-    fn = @(x) arrayfun (fn, x);  # Create a new fn that accepts vectors
-    y0 = feval (fn, x0);
-    warning ("fplot: FN is not a vectorized function which reduces performance");
+    fcn = @(x) arrayfun (fcn, x);  # Create a new fcn that accepts vectors
+    y0 = feval (fcn, x0);
+    warning ("fplot: FCN is not a vectorized function which reduces performance");
   end_try_catch
 
   x = linspace (limits(1), limits(2), n)';
-  y = feval (fn, x);
+  y = feval (fcn, x);
 
   if (rows (x0) == rows (y0))
     fcn_transpose = false;
@@ -177,7 +190,7 @@ function [X, Y] = fplot (varargin)
     y0 = y0.';
     y = y.';
   else
-    error ("fplot: invalid function FN (# of outputs not equal to inputs)");
+    error ("fplot: invalid function FCN (# of outputs not equal to inputs)");
   endif
 
   err0 = Inf;
@@ -204,7 +217,7 @@ function [X, Y] = fplot (varargin)
     err0 = err;
     n = 2 * (n - 1) + 1;
     x = linspace (limits(1), limits(2), n)';
-    y = feval (fn, x);
+    y = feval (fcn, x);
     if (fcn_transpose)
       y = y.';
     endif
@@ -217,18 +230,24 @@ function [X, Y] = fplot (varargin)
     if (isempty (hax))
       hax = gca ();
     endif
-    plot (hax, x, y, fmt{:});
-    axis (hax, limits);
-    ## FIXME: If hold is on, then this erases the existing legend rather than
-    ##        adding to it.
-    if (isvector (y))
-      legend (hax, nam);
-    else
-      for i = 1:columns (y)
-        nams{i} = sprintf ("%s(:,%i)", nam, i);
-      endfor
-      legend (hax, nams{:});
+    hl = plot (hax, x, y, fmt{:});
+    if (isempty (get (hl(1), "displayname")))
+      ## Set displayname for legend if FMT did not contain a name.
+      if (isvector (y))
+        set (hl, "displayname", nam);
+      else
+        for i = 1:columns (y)
+          nams{i} = sprintf ("%s(:,%i)", nam, i);
+        endfor
+        set (hl, {"displayname"}, nams(:));
+      endif
     endif
+    ## Properties passed as input arguments override other properties.
+    if (! isempty (prop_vals))
+      set (hl, prop_vals{:});
+    endif
+    axis (hax, limits);
+    legend (hax, "show");
   endif
 
 endfunction
@@ -259,32 +278,54 @@ endfunction
 
 %!test
 %! ## Function requiring transpose
-%! fn = @(x) 2 * x(:).';
-%! [x, y] = fplot (fn, [-1, 1]);
+%! fcn = @(x) 2 * x(:).';
+%! [x, y] = fplot (fcn, [-1, 1]);
 %! assert (columns (y) == 1);
 %! assert (rows (x) == rows (y));
 %! assert (y, 2*x);
 
 %!test
 %! ## Constant value function
-%! fn = @(x) 0;
-%! [x, y] = fplot (fn, [-1, 1]);
+%! fcn = @(x) 0;
+%! [x, y] = fplot (fcn, [-1, 1]);
 %! assert (columns (y) == 1);
 %! assert (rows (x) == rows (y));
 %! assert (y, repmat ([0], size (x)));
 
+%!test <*59274>
+%! ## Manual displayname overrides automatic legend entry
+%! hf = figure ("visible", "off");
+%! unwind_protect
+%!   fplot (@sin, [0, 3], "displayname", "mysin");
+%!   hl = legend ();
+%!   assert (get (hl, "string"), {"mysin"});
+%! unwind_protect_cleanup
+%!   close (hf);
+%! end_unwind_protect
+
+%!test <*59274>
+%! ## displayname in format string overrides automatic legend entry
+%! hf = figure ("visible", "off");
+%! unwind_protect
+%!   fplot (@sin, [0, 3], "+;mysin;");
+%!   hl = legend ();
+%!   assert (get (hl, "string"), {"mysin"});
+%! unwind_protect_cleanup
+%!   close (hf);
+%! end_unwind_protect
+
 ## Test input validation
-%!error fplot ()
-%!error fplot (1,2,3,4,5,6)
-%!error <FN must be a function handle> fplot (1, [0 1])
+%!error <Invalid call> fplot ()
+%!error <Invalid call> fplot (1,2,3,4,5,6)
+%!error <FCN must be a function handle> fplot (1, [0 1])
 %!error <LIMITS must be a real vector> fplot (@cos, [i, 2*i])
 %!error <LIMITS must be a real vector with 2 or 4> fplot (@cos, [1])
 %!error <LIMITS must be a real vector with 2 or 4> fplot (@cos, [1 2 3])
 %!error <bad input in position 2> fplot (@cos, "linewidth")
 %!error <bad input in position 3> fplot (@cos, [-1,1], {1})
-%!warning <FN is not a vectorized function>
-%! fn = @(x) 0;
-%! [x,y] = fplot (fn, [-1,1]);
-%!error <invalid function FN>
-%! fn = @(x) [x;x];
-%! fplot (fn, [-1,1]);
+%!warning <FCN is not a vectorized function>
+%! fcn = @(x) 0;
+%! [x,y] = fplot (fcn, [-1,1]);
+%!error <invalid function FCN>
+%! fcn = @(x) [x;x];
+%! fplot (fcn, [-1,1]);
