@@ -1,20 +1,27 @@
-## Copyright (C) 1996-2017 John W. Eaton
+########################################################################
+##
+## Copyright (C) 1996-2023 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## Octave is free software: you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or (at
-## your option) any later version.
+## the Free Software Foundation, either version 3 of the License, or
+## (at your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details.
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn  {} {} plot3 (@var{x}, @var{y}, @var{z})
@@ -80,6 +87,8 @@
 ## Multiple property-value pairs may be specified which will affect the line
 ## objects drawn by @code{plot3}.  If the @var{fmt} argument is supplied it
 ## will format the line objects in the same manner as @code{plot}.
+## The full list of properties is documented at
+## @ref{Line Properties}.
 ##
 ## If the first argument @var{hax} is an axes handle, then plot into this axes,
 ## rather than the current axes returned by @code{gca}.
@@ -98,10 +107,7 @@
 ## @seealso{ezplot3, plot}
 ## @end deftypefn
 
-## Author: Paul Kienzle
-##         (modified from __plt__.m)
-
-function retval = plot3 (varargin)
+function h = plot3 (varargin)
 
   [hax, varargin, nargs] = __plt_get_axis_arg__ ("plot3", varargin{:});
 
@@ -124,6 +130,7 @@ function retval = plot3 (varargin)
     properties = {};
     tlgnd = {};
     hlgnd = [];
+    htmp = [];
     idx = 0;
 
     ## Gather arguments, decode format, and plot lines.
@@ -212,9 +219,10 @@ function retval = plot3 (varargin)
             color = __next_line_color__ ();
           endif
 
-          htmp(++idx) = line (x(:, i), y(:, i), z(:, i),
-                              "color", color, "linestyle", linestyle,
-                              "marker", marker, properties{:});
+          htmp(++idx) = __go_line__ (hax, "xdata", x(:, i), "ydata", y(:, i),
+                                     "zdata", z(:, i),
+                                     "color", color, "linestyle", linestyle,
+                                     "marker", marker, properties{:});
           key = options.key;
           if (! isempty (key))
             hlgnd = [hlgnd, htmp(idx)];
@@ -267,9 +275,10 @@ function retval = plot3 (varargin)
             color = __next_line_color__ ();
           endif
 
-          htmp(++idx) = line (x(:, i), y(:, i), z(:, i),
-                              "color", color, "linestyle", linestyle,
-                              "marker", marker, properties{:});
+          htmp(++idx) = __go_line__ (hax, "xdata", x(:, i), "ydata", y(:, i),
+                                     "zdata", z(:, i),
+                                     "color", color, "linestyle", linestyle,
+                                     "marker", marker, properties{:});
           key = options.key;
           if (! isempty (key))
             hlgnd = [hlgnd, htmp(idx)];
@@ -342,9 +351,10 @@ function retval = plot3 (varargin)
           color = __next_line_color__ ();
         endif
 
-        htmp(++idx) = line (x(:, i), y(:, i), z(:, i),
-                            "color", color, "linestyle", linestyle,
-                            "marker", marker, properties{:});
+        htmp(++idx) = __go_line__ (hax, "xdata", x(:, i), "ydata", y(:, i),
+                                   "zdata", z(:, i),
+                                   "color", color, "linestyle", linestyle,
+                                   "marker", marker, properties{:});
         key = options.key;
         if (! isempty (key))
           hlgnd = [hlgnd, htmp(idx)];
@@ -367,8 +377,8 @@ function retval = plot3 (varargin)
     endif
   end_unwind_protect
 
-  if (nargout > 0 && idx > 0)
-    retval = htmp;
+  if (nargout > 0)
+    h = htmp;
   endif
 
 endfunction
