@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 1996-2021 The Octave Project Developers
+## Copyright (C) 1996-2023 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -49,6 +49,8 @@ function [h, varargin, narg] = __plt_get_axis_arg__ (caller, varargin)
   elseif (numel (varargin) > 1)
     ## FIXME: This can be fooled by any string "parent" such as
     ##        the prop/val pair "tag"/"parent".
+    ## varargin may contain char arrays. Silence respective warning.
+    warning ("off", "Octave:charmat-truncated", "local");
     parent = find (strcmpi (varargin, "parent"), 1, "last");
     if (! isempty (parent))
       if (parent == numel (varargin) || ! ishghandle (varargin{parent+1}))
