@@ -1,4 +1,9 @@
-## Copyright (C) 1994-2019 John W. Eaton
+########################################################################
+##
+## Copyright (C) 1994-2023 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -15,6 +20,8 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn  {} {@var{b} =} deconv (@var{y}, @var{a})
@@ -30,10 +37,6 @@
 ## @seealso{conv, residue}
 ## @end deftypefn
 
-## Author: Tony Richardson <arichard@stark.cc.oh.us>
-## Created: June 1994
-## Adapted-By: jwe
-
 function [b, r] = deconv (y, a)
 
   if (nargin != 2)
@@ -77,6 +80,7 @@ function [b, r] = deconv (y, a)
 
 endfunction
 
+
 %!test
 %! [b, r] = deconv ([3, 6, 9, 9], [1, 2, 3]);
 %! assert (b, [3, 0]);
@@ -114,22 +118,22 @@ endfunction
 %! y = (10:-1:1);
 %! a = (4:-1:1);
 %! [b, r] = deconv (y, a);
-%! assert (conv (a, b) + r, y, eps)
+%! assert (conv (a, b) + r, y, eps);
 
-%!test <51221>
+%!test <*51221>
 %! a = [1.92306958582241e+15, 3.20449986572221e+24, 1.34271290136344e+32, ...
 %!     2.32739765751038e+38];
 %! b = [7.33727670161595e+27, 1.05919311870816e+36, 4.56169848520627e+42];
 %! [div, rem] = deconv (a, b);
-%! assert (rem, [0, 0, -2.89443678763879e+32  -1.58695290534499e+39], -10*eps)
+%! assert (rem, [0, 0, -2.89443678763879e+32  -1.58695290534499e+39], -10*eps);
 %! a(2) = 3.204499865722215e+24;
 %! [div, rem] = deconv (a, b);
-%! assert (rem, [0, 0, -2.89443678763879e+32  -1.58695290534499e+39], -10*eps)
+%! assert (rem, [0, 0, -2.89443678763879e+32  -1.58695290534499e+39], -10*eps);
 
 %!test
 %! [b, r] = deconv ([1, 1], 1);
-%! assert (r, [0, 0])
+%! assert (r, [0, 0]);
 
 %!test
 %! [b, r] = deconv ([1; 1], 1);
-%! assert (r, [0; 0])
+%! assert (r, [0; 0]);
