@@ -1,23 +1,30 @@
-## Copyright (C) 1995-2017 Kurt Hornik
+########################################################################
+##
+## Copyright (C) 1995-2023 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## Octave is free software: you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or (at
-## your option) any later version.
+## the Free Software Foundation, either version 3 of the License, or
+## (at your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details.
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
-## @deftypefn {} {} autoreg_matrix (@var{y}, @var{k})
+## @deftypefn {} {@var{x} =} autoreg_matrix (@var{y}, @var{k})
 ## Given a time series (vector) @var{y}, return a matrix with ones in the first
 ## column and the first @var{k} lagged values of @var{y} in the other columns.
 ##
@@ -28,10 +35,7 @@
 ## The resulting matrix may be used as a regressor matrix in autoregressions.
 ## @end deftypefn
 
-## Author: KH <Kurt.Hornik@wu-wien.ac.at>
-## Description: Design matrix for autoregressions
-
-function X = autoreg_matrix (y, k)
+function x = autoreg_matrix (y, k)
 
   if (nargin != 2)
     print_usage ();
@@ -43,9 +47,9 @@ function X = autoreg_matrix (y, k)
 
   T = length (y);
   y = reshape (y, T, 1);
-  X = ones (T, k+1);
-  for j = 1 : k;
-    X(:, j+1) = [(zeros (j, 1)); y(1:T-j)];
+  x = ones (T, k+1);
+  for j = 1 : k
+    x(:, j+1) = [(zeros (j, 1)); y(1:T-j)];
   endfor
 
 endfunction
@@ -59,6 +63,6 @@ endfunction
 %! B(:,1) = 1;
 %! assert (autoreg_matrix (A,K), B);
 
-%!error autoreg_matrix ()
-%!error autoreg_matrix (1)
+%!error <Invalid call> autoreg_matrix ()
+%!error <Invalid call> autoreg_matrix (1)
 %!error autoreg_matrix (ones (4,1), 5)
