@@ -1,4 +1,9 @@
-## Copyright (C) 1996-2019 Kurt Hornik
+########################################################################
+##
+## Copyright (C) 1996-2023 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -15,9 +20,11 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
-## @deftypefn {} {} rindex (@var{s}, @var{t})
+## @deftypefn {} {@var{n} =} rindex (@var{s}, @var{t})
 ## Return the position of the last occurrence of the character string
 ## @var{t} in the character string @var{s}, or 0 if no occurrence is
 ## found.
@@ -39,10 +46,6 @@
 ## @seealso{find, index}
 ## @end deftypefn
 
-## Author: Kurt Hornik <Kurt.Hornik@wu-wien.ac.at>
-## Adapted-By: jwe
-## This is patterned after the AWK function of the same name.
-
 function n = rindex (s, t)
 
   if (nargin != 2)
@@ -64,6 +67,6 @@ endfunction
 %! assert (rindex (str, "o"), [5; 2; 3; 2]);
 
 ## Test input validation
-%!error rindex ()
+%!error <Invalid call> rindex ()
 %!error rindex ("foo")
 %!error rindex ("foo", "bar", "last")
